@@ -39,7 +39,9 @@
 #include <wx/utils.h>
 #include <wx/wfstream.h>
 #include <wx/xml/xml.h>
+#include <wx/mstream.h>
 #include <algorithm>
+#include "builtin_commands.h"
 
 AutoComplete::AutoComplete(Configuration *configuration) : wxEvtHandler() {
   std::vector<wxString> emptyList;
@@ -58,6 +60,37 @@ std::vector<wxString> AutoComplete::GetDemoFilesList() {
   return m_builtInDemoFiles;
 }
 
+std::vector<wxString> AutoComplete::GetSymbolList()
+{
+  const std::lock_guard<std::mutex> lock(m_keywordsLock);
+  return m_wordList.at(command);
+}
+
+void AutoComplete::LoadBuiltinSymbols() {
+  wxMemoryInputStream istream(BUILTIN_COMMANDS, BUILTIN_COMMANDS_SIZE);
+  wxTextInputStream txtstrm(istream);
+  wxString line;
+  const std::lock_guard<std::mutex> lock(m_keywordsLock);
+  while(!istream.Eof())
+    {
+      line = txtstrm.ReadLine();
+      auto parenPos = line.Find(wxS("("));
+      if(parenPos != wxNOT_FOUND)
+        {
+          m_wordList.at(tmplte).push_back(line);
+          m_wordList.at(command).push_back(line.Left(parenPos));
+        }
+      else
+        m_wordList.at(command).push_back(line);
+    }
+  std::sort(m_wordList.at(tmplte).begin(), m_wordList.at(tmplte).end());
+  auto newEnd = std::unique(m_wordList.at(tmplte).begin(), m_wordList.at(tmplte).end());
+  m_wordList.at(tmplte).erase(newEnd, m_wordList.at(tmplte).end());
+  std::sort(m_wordList.at(command).begin(), m_wordList.at(command).end());
+  newEnd = std::unique(m_wordList.at(command).begin(), m_wordList.at(command).end());
+  m_wordList.at(command).erase(newEnd, m_wordList.at(command).end());
+}
+
 bool AutoComplete::HasDemofile(wxString commandname)
 {
   const std::lock_guard<std::mutex> lock(m_keywordsLock);
@@ -78,21 +111,39 @@ void AutoComplete::ClearDemofileList() {
 void AutoComplete::AddSymbols(wxString xml) {
   if(m_addSymbols_backgroundThread.joinable())
     m_addSymbols_backgroundThread.join();
-  wxLogMessage(_("Scheduling a background task that compiles a new list "
-                 "of autocompletable maxima commands."));
 
-  wxString sharedir = m_configuration->MaximaShareDir();
-  sharedir.Replace("\n", "");
-  sharedir.Replace("\r", "");
-
-  m_addSymbols_backgroundThread = std::thread(&AutoComplete::AddSymbols_Backgroundtask,
-                                              this, xml);
+  if((m_configuration->UseThreads() && xml.Length() > 300))
+    m_addSymbols_backgroundThread = std::thread(&AutoComplete::AddSymbols_Backgroundtask_string,
+                                                this, std::move(xml));
+  else
+    AddSymbols_Backgroundtask_string(std::move(xml));
 }
 
-void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
+void AutoComplete::AddSymbols(wxXmlDocument xml) {
+  if(m_addSymbols_backgroundThread.joinable())
+    {
+      wxLogMessage(_("Waiting for m_addSymbols_backgroundThread to finish"));
+      m_addSymbols_backgroundThread.join();
+    }
+  wxLogMessage(_("Scheduling a background task that compiles a new list "
+                 "of autocompletable maxima commands."));
+  
+  if(m_configuration->UseThreads())
+    m_addSymbols_backgroundThread = std::thread(&AutoComplete::AddSymbols_Backgroundtask,
+                                                this, std::move(xml));
+  else
+    AddSymbols_Backgroundtask(std::move(xml));
+    
+}
+
+void AutoComplete::AddSymbols_Backgroundtask_string(wxString xml) {
   wxXmlDocument xmldoc;
   wxStringInputStream xmlStream(xml);
   xmldoc.Load(xmlStream, wxS("UTF-8"));
+  AddSymbols_Backgroundtask(xmldoc);
+}
+
+void AutoComplete::AddSymbols_Backgroundtask(wxXmlDocument xmldoc) {
   wxXmlNode *node = xmldoc.GetRoot();
   if (node != NULL) {
     wxXmlNode *children = node->GetChildren();
@@ -102,7 +153,8 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
-            AddSymbol(name, command);
+            const std::lock_guard<std::mutex> lock(m_keywordsLock);
+            m_wordList.at(command).push_back(name);
           }
         }
 
@@ -110,7 +162,8 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
-            AddSymbol(name, tmplte);
+            const std::lock_guard<std::mutex> lock(m_keywordsLock);
+            m_wordList.at(tmplte).push_back(name);
           }
         }
 
@@ -118,7 +171,8 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
-            AddSymbol(name, unit);
+            const std::lock_guard<std::mutex> lock(m_keywordsLock);
+            m_wordList.at(unit).push_back(name);
           }
         }
 
@@ -126,12 +180,31 @@ void AutoComplete::AddSymbols_Backgroundtask(wxString xml) {
           wxXmlNode *val = children->GetChildren();
           if (val) {
             wxString name = val->GetContent();
-            AddSymbol(name, command);
+            const std::lock_guard<std::mutex> lock(m_keywordsLock);
+            m_wordList.at(command).push_back(name);
           }
         }
       }
       children = children->GetNext();
     }
+    {
+      const std::lock_guard<std::mutex> lock(m_keywordsLock);
+      std::sort(m_wordList.at(command).begin(), m_wordList.at(command).end());
+      auto newEnd = std::unique(m_wordList.at(command).begin(), m_wordList.at(command).end());
+      m_wordList.at(command).erase(newEnd, m_wordList.at(command).end());
+    }
+    {
+      const std::lock_guard<std::mutex> lock(m_keywordsLock);
+      std::sort(m_wordList.at(unit).begin(), m_wordList.at(unit).end());
+      auto newEnd = std::unique(m_wordList.at(unit).begin(), m_wordList.at(unit).end());
+      m_wordList.at(unit).erase(newEnd, m_wordList.at(unit).end());
+    }
+    {
+      const std::lock_guard<std::mutex> lock(m_keywordsLock);
+      std::sort(m_wordList.at(tmplte).begin(), m_wordList.at(tmplte).end());
+      auto newEnd = std::unique(m_wordList.at(tmplte).begin(), m_wordList.at(tmplte).end());
+      m_wordList.at(tmplte).erase(newEnd, m_wordList.at(tmplte).end());
+    }
   }
 }
 
@@ -158,18 +231,34 @@ void AutoComplete::LoadSymbols() {
   sharedir.Replace("\n", "");
   sharedir.Replace("\r", "");
   if(m_addFiles_backgroundThread.joinable())
-    m_addFiles_backgroundThread.join();
+    {
+      wxLogMessage(_("Waiting for m_addFiles_backgroundThread to finish"));
+      m_addFiles_backgroundThread.join();
+    }
   if(m_addSymbols_backgroundThread.joinable())
-    m_addSymbols_backgroundThread.join();
-  m_addSymbols_backgroundThread = std::thread(&AutoComplete::BuiltinSymbols_BackgroundTask, this);
-  m_addFiles_backgroundThread = std::thread(&AutoComplete::LoadableFiles_BackgroundTask, this, sharedir);
+    {
+      wxLogMessage(_("Waiting for m_addSymbols_backgroundThread to finish"));
+      m_addSymbols_backgroundThread.join();
+    }
+  if(m_configuration->UseThreads())
+    {
+      m_addSymbols_backgroundThread = std::thread(&AutoComplete::BuiltinSymbols_BackgroundTask,
+                                                  this);
+      m_addFiles_backgroundThread = std::thread(&AutoComplete::LoadableFiles_BackgroundTask,
+                                                this, sharedir);
+    }
+  else
+    {
+      BuiltinSymbols_BackgroundTask();
+      LoadableFiles_BackgroundTask(sharedir);
+    }
 }
 
 void AutoComplete::BuiltinSymbols_BackgroundTask() {
   {
     const std::lock_guard<std::mutex> lock(m_keywordsLock);
     for(auto &wordlist:m_wordList)
-    wordlist.clear();
+      wordlist.clear();
   }
   LoadBuiltinSymbols();
 
@@ -184,6 +273,8 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
     {
       const std::lock_guard<std::mutex> lock(m_keywordsLock);
       std::sort(wordlist.begin(), wordlist.end());
+      auto newEnd = std::unique(wordlist.begin(), wordlist.end());
+      wordlist.erase(newEnd, wordlist.end());
     }
 
   wxString line;
@@ -191,8 +282,6 @@ void AutoComplete::BuiltinSymbols_BackgroundTask() {
   /// Load private symbol list (do something different on Windows).
   wxString privateList;
   privateList = Dirstructure::Get()->UserAutocompleteFile();
-  wxLogMessage(_("Trying to load a list of autocompletable symbols from file %s"),
-               privateList.utf8_str());
   if (wxFileExists(privateList)) {
     wxTextFile priv(privateList);
 
@@ -267,8 +356,6 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     else {
       wxFileName shareDir(sharedir + "/");
       shareDir.MakeAbsolute();
-      wxLogMessage(_("Autocompletion: Scanning %s recursively for loadable lisp files."),
-                   shareDir.GetFullPath().utf8_str());
       wxDir maximadir(shareDir.GetFullPath());
       if (maximadir.IsOpened())
         maximadir.Traverse(maximaLispIterator); // todo
@@ -277,13 +364,9 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     wxFileName userDir(Dirstructure::Get()->UserConfDir() + "/");
     userDir.MakeAbsolute();
     wxDir maximauserfilesdir(userDir.GetFullPath());
-    wxLogMessage(_("Autocompletion: Scanning %s for loadable lisp files."),
-                 userDir.GetFullPath().utf8_str());
     if (maximauserfilesdir.IsOpened())
       maximauserfilesdir.Traverse(userLispIterator);
     const std::lock_guard<std::mutex> lock(m_keywordsLock);
-    long num = m_builtInLoadFiles.size();
-    wxLogMessage(_("Found %li loadable files."), num);
   }
 
   // Prepare a list of all built-in demos of maxima.
@@ -294,15 +377,10 @@ void AutoComplete::LoadableFiles_BackgroundTask(wxString sharedir) {
     demoDir.MakeAbsolute();
     demoDir.RemoveLastDir();
     GetDemoFiles_includingSubdirs maximaLispIterator(m_builtInDemoFiles, &m_keywordsLock);
-    wxLogMessage(_("Autocompletion: Scanning %s for loadable demo files."),
-                 demoDir.GetFullPath().utf8_str());
-
     wxDir maximadir(demoDir.GetFullPath());
     if (maximadir.IsOpened())
       maximadir.Traverse(maximaLispIterator);
     const std::lock_guard<std::mutex> lock(m_keywordsLock);
-    long num = m_builtInDemoFiles.size();
-    wxLogMessage(_("Found %li demo files."), num);
   }
   const std::lock_guard<std::mutex> lock(m_keywordsLock);
   std::sort(m_builtInLoadFiles.begin(), m_builtInLoadFiles.end());
@@ -471,7 +549,10 @@ std::vector<wxString> AutoComplete::CompleteSymbol(wxString partial,
     }
   }
 
+  const std::lock_guard<std::mutex> lock(m_keywordsLock);
   std::sort(completions.begin(), completions.end());
+  auto newEnd = std::unique(completions.begin(), completions.end());
+  completions.erase(newEnd, completions.end());
   if (perfectCompletions.size() > 0)
     return perfectCompletions;
   return completions;
@@ -489,7 +570,9 @@ void AutoComplete::AddSymbol(wxString fun, autoCompletionType type) {
     fun = fun.Mid(6);
     type = unit;
   }
-
+  auto spacepos = fun.Find(" ");
+  if(spacepos != wxNOT_FOUND)
+    fun = fun.Left(spacepos);
   /// Add symbols
   {
     const std::lock_guard<std::mutex> lock(m_keywordsLock);
