@@ -35,6 +35,7 @@
 #include <memory>
 #include <mutex>
 #include <wx/wx.h>
+#include <wx/xml/xml.h>
 #include <wx/event.h>
 #include <wx/dir.h>
 #include <vector>
@@ -56,11 +57,7 @@
 */
 class AutoComplete : public wxEvtHandler
 {
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, int> WorksheetWords;
-#else
-  WX_DECLARE_STRING_HASH_MAP(int, WorksheetWords);
-#endif
+  typedef std::unordered_map <wxString, int, wxStringHash> WorksheetWords;
 public:
   using WordList = std::vector<wxString>;
 
@@ -79,7 +76,7 @@ public:
   explicit AutoComplete(Configuration *configuration);
 
   //! The destructor of AutoComplete
-  ~AutoComplete();
+  virtual ~AutoComplete();
 
   //! Load all autocomplete symbols wxMaxima knows about by itself
   void LoadSymbols();
@@ -90,14 +87,19 @@ public:
     suspiciously long.
     For the same reason it has been split into a separate file.
   */
-  bool LoadBuiltinSymbols();
+  void LoadBuiltinSymbols();
 
   //! Manually add an autocompletable symbol to our symbols lists
   void AddSymbol(wxString fun, autoCompletionType type = command);
   //! Interprets the XML autocompletable symbol list maxima can send us
   void AddSymbols(wxString xml);
+  //! Interprets the XML autocompletable symbol list maxima can send us
+  void AddSymbols(wxXmlDocument xml);
   //! The real work of AddSymbols is made here and in the background
-  void AddSymbols_Backgroundtask(wxString xml);
+  void AddSymbols_Backgroundtask_string(wxString xml);
+  //! The real work of AddSymbols is made here and in the background
+  void AddSymbols_Backgroundtask(wxXmlDocument xmldoc);
+
 
   //! Replace the list of files in the directory the worksheet file is in to the demo files list
   void UpdateDemoFiles(wxString partial, wxString maximaDir);
@@ -121,6 +123,8 @@ public:
   static wxString FixTemplate(wxString templ);
   //! Returns a list of demo files we know of
   std::vector<wxString> GetDemoFilesList();
+  //! Returns a list of Symbols we know
+  std::vector<wxString> GetSymbolList();
   //! Does a demo file for this command exist?
   bool HasDemofile(wxString commandname);
 
