@@ -36,16 +36,17 @@
 #include <wx/listctrl.h>
 #include <wx/textfile.h>
 #include <wx/wupdlock.h>
+#include <algorithm>
 
 void AutocompletePopup::UpdateResults() {
   m_completions = m_autocomplete->CompleteSymbol(m_partial, m_type);
-  m_completions.Sort();
+  std::sort(m_completions.begin(), m_completions.end());
 
-  switch (m_completions.GetCount()) {
+  switch (m_completions.size()) {
   case 1:
     if ((m_type == AutoComplete::esccommand) && (m_partial.Length() < 2)) {
       DeleteAllItems();
-      for (unsigned int i = 0; i < m_completions.GetCount(); i++)
+      for (unsigned int i = 0; i < m_completions.size(); i++)
         InsertItem(i, m_completions[i]);
 
       Select(0);
@@ -55,10 +56,10 @@ void AutocompletePopup::UpdateResults() {
 
     if (m_type != AutoComplete::esccommand) {
       m_editor->ReplaceSelection(m_editor->GetSelectionString(),
-                                 m_completions[0]);
+                                 m_completions.at(0));
       m_editor->ClearSelection();
     } else
-      m_editor->InsertEscCommand(m_completions[0]);
+      m_editor->InsertEscCommand(m_completions.at(0));
 
     m_parent->GetParent()->Refresh();
     if (!m_editor->IsActive())
@@ -74,7 +75,7 @@ void AutocompletePopup::UpdateResults() {
     return void(Destroy());
   default:
     DeleteAllItems();
-    for (unsigned int i = 0; i < m_completions.GetCount(); i++)
+    for (unsigned int i = 0; i < m_completions.size(); i++)
       InsertItem(i, m_completions[i]);
 
     Select(0);
@@ -85,19 +86,19 @@ void AutocompletePopup::UpdateResults() {
 void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
   switch (event.GetKeyCode()) {
   case WXK_TAB:
-    if (m_completions.GetCount() > 0) {
+    if (m_completions.size() > 0) {
       wxChar ch;
       bool addChar = true;
       wxString word = m_editor->GetSelectionString();
-      size_t index = word.Length();
+      std::size_t index = word.Length();
       do {
-        if (m_completions[0].Length() <= index)
+        if (m_completions.at(0).Length() <= index)
           addChar = false;
         else {
-          ch = m_completions[0][index];
-          for (size_t i = 0; i < m_completions.GetCount(); i++)
-            if ((m_completions[i].Length() < index + 1) ||
-                (m_completions[i][index] != ch))
+          ch = m_completions.at(0).at(index);
+          for (std::size_t i = 0; i < m_completions.size(); i++)
+            if ((m_completions.at(i).Length() < index + 1) ||
+                (m_completions.at(i).at(index) != ch))
               addChar = false;
         }
 
@@ -119,12 +120,12 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
     if (selection < 0)
       selection = 0;
 
-    if (m_completions.GetCount() > 0) {
+    if (m_completions.size() > 0) {
       if (m_type != AutoComplete::esccommand)
         m_editor->ReplaceSelection(m_editor->GetSelectionString(),
-                                   m_completions[selection]);
+                                   m_completions.at(selection));
       else
-        m_editor->InsertEscCommand(m_completions[selection]);
+        m_editor->InsertEscCommand(m_completions.at(selection));
     }
     m_parent->GetParent()->Refresh();
     if (!m_editor->IsActive())
@@ -137,7 +138,7 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
       int selection = GetNextItem(0, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
       if (selection < 0)
         selection = 0;
-      m_editor->InsertEscCommand(m_completions[selection]);
+      m_editor->InsertEscCommand(m_completions.at(selection));
     }
     m_parent->GetParent()->Refresh();
     if (!m_editor->IsActive())
@@ -150,7 +151,7 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
       Select(selection - 1);
       Focus(selection - 1);
     } else {
-      if (m_completions.GetCount() > 0) {
+      if (m_completions.size() > 0) {
         Select(0);
         Focus(0);
       }
@@ -164,7 +165,7 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
     if (selection < 0)
       selection = 0;
 
-    if (m_completions.GetCount() > 0) {
+    if (m_completions.size() > 0) {
       Select(selection);
       Focus(selection);
     }
@@ -176,10 +177,10 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
     unsigned int selection =
       GetNextItem(0, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
     selection += 8;
-    if (selection >= m_completions.GetCount())
-      selection = m_completions.GetCount() - 1;
+    if (selection >= m_completions.size())
+      selection = m_completions.size() - 1;
 
-    if (m_completions.GetCount() > 0) {
+    if (m_completions.size() > 0) {
       Select(selection);
       Focus(selection);
     }
@@ -187,13 +188,14 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
   }
   case WXK_DOWN:
   case WXK_NUMPAD_DOWN: {
-    long selection = GetNextItem(0, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if (selection < 0)
-      selection = 0;
+    auto sel = GetNextItem(0, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
+    if (sel < 0)
+      sel = 0;
+    std::size_t selection = sel;
     selection++;
-    if (selection >= (long)m_completions.GetCount())
+    if (selection >= m_completions.size())
       selection--;
-    if (m_completions.GetCount() > 0) {
+    if (m_completions.size() > 0) {
       Select(selection);
       Focus(selection);
     }
@@ -225,7 +227,7 @@ void AutocompletePopup::OnKeyDown(wxKeyEvent &event) {
 bool AutocompletePopup::Create(wxWindow *parent) {
   bool retval = wxListView::Create(parent, 1, m_position, wxDefaultSize,
                                    wxLC_ALIGN_LEFT | wxLC_REPORT |
-				   wxLC_NO_HEADER | wxLC_SINGLE_SEL);
+                                   wxLC_NO_HEADER | wxLC_SINGLE_SEL);
   //  wxWindowUpdateLocker lock(this);
   InsertColumn(0, wxEmptyString);
   UpdateResults();
@@ -233,7 +235,7 @@ bool AutocompletePopup::Create(wxWindow *parent) {
 
   wxSize minSize;
   wxSize optimumSize = wxSize(-1, 0);
-  for (size_t i = 0; i < m_completions.GetCount(); i++) {
+  for (std::size_t i = 0; i < m_completions.size(); i++) {
     wxRect itemRect;
     if (GetItemRect(i, itemRect)) {
       if (optimumSize.x < itemRect.GetWidth())
@@ -260,7 +262,7 @@ void AutocompletePopup::OnClick(wxMouseEvent &WXUNUSED(event)) {
 
   if (m_value < 0)
     m_value = 0;
-  m_partial = m_completions[m_value];
+  m_partial = m_completions.at(m_value);
   if (m_type != AutoComplete::esccommand)
     m_editor->ReplaceSelection(m_editor->GetSelectionString(), m_partial);
   else
