@@ -126,32 +126,33 @@ void BTextCtrl::CloseParenthesis(wxString open, wxString close, bool fromOpen) {
   if (from == to) // nothing selected
     {
       wxString text = GetValue();
-      wxString charHere = wxS(" "); // text.GetChar((size_t)GetInsertionPoint());
-      size_t insp = GetInsertionPoint();
+      wxString charHere = wxS(" "); // text.GetChar((std::size_t)GetInsertionPoint());
+      std::size_t insp = GetInsertionPoint();
 
       if (!fromOpen && charHere == close)
-	SetInsertionPoint(insp + 1);
+        SetInsertionPoint(insp + 1);
       else {
-	wxString newtext = (insp > 0 ? text.SubString(0, insp - 1) : wxS("")) +
-	  (fromOpen ? open : wxS("")) + close +
-	  text.SubString(insp, text.length());
+        wxString newtext = (insp > 0 ? text.SubString(0, insp - 1) : wxS("")) +
+          (fromOpen ? open : wxS("")) + close +
+          text.SubString(insp, text.length());
 
-	ChangeValue(newtext);
+        ChangeValue(newtext);
 
-	SetInsertionPoint(insp + 1);
+        SetInsertionPoint(insp + 1);
       }
     } else {
     wxString text = GetValue();
 
-    wxString newtext = (from > 0 ? text.SubString(0, from - 1) : wxS("")) +
-      open + text.SubString(from, to - 1) + close +
-      text.SubString(to, text.length());
+    if(from >= 0) {
+      wxString newtext = text.SubString(0, static_cast<std::size_t>(from) - 1) +
+        open + text.SubString(from, static_cast<std::size_t>(to) - 1) + close +
+        text.SubString(to, text.length());
 
-    ChangeValue(newtext);
-
-    if (fromOpen)
-      SetInsertionPoint(from + 1);
-    else
-      SetInsertionPoint(to + 1);
+      ChangeValue(newtext);
+      if (fromOpen)
+        SetInsertionPoint(from + 1);
+      else
+        SetInsertionPoint(to + 1);
+    }
   }
 }
