@@ -28,8 +28,8 @@
 #include <wx/display.h>
 #include <wx/fontenum.h>
 #include <wx/hashmap.h>
-#include "LoggingMessageDialog.h"
-#include "TextStyle.h"
+#include "dialogs/LoggingMessageDialog.h"
+#include "cells/TextStyle.h"
 #include <cstdint>
 #include <memory>
 #include <mutex>
@@ -138,15 +138,9 @@ public:
     display_1dASCII
   };
 
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, bool> StringBoolHash;
-  typedef std::unordered_map <wxString, wxString> RenderablecharsHash;
-  typedef std::unordered_map <wxString, int> StringHash;
-#else
-  WX_DECLARE_STRING_HASH_MAP(bool, StringBoolHash);
-  WX_DECLARE_STRING_HASH_MAP(wxString, RenderablecharsHash);
-  WX_DECLARE_STRING_HASH_MAP(int, StringHash);
-#endif
+  typedef std::unordered_map <wxString, bool, wxStringHash> StringBoolHash;
+  typedef std::unordered_map <wxString, wxString, wxStringHash> RenderablecharsHash;
+  typedef std::unordered_map <wxString, int, wxStringHash> StringHash;
   /*! All maxima operator names we know
    */
   StringHash m_maximaOperators;
@@ -198,7 +192,7 @@ public:
   //! Get the brush to be used for worksheet objects that provide a mouse-over tooltip
   wxBrush GetTooltipBrush() const {return m_tooltipBrush;}
 
-  ~Configuration();
+  virtual ~Configuration();
 
   /*! Where to store the configuration.
 
@@ -1065,6 +1059,8 @@ public:
   */
   std::int_fast32_t CellCfgCnt() const {return m_cellCfgCnt;}
   void RecalculateForce() { m_cellCfgCnt++; }
+  bool UseThreads(){return m_use_threads;}
+  static void UseThreads(bool use){m_use_threads = use;}
 private:
   //! Which styles affect how code is displayed?
   std::vector<TextStyle> m_codeStyles;
@@ -1257,6 +1253,7 @@ private:
   maximaHelpFormat m_maximaHelpFormat;
   wxTextCtrl *m_lastActiveTextCtrl = NULL;
   std::int_fast32_t m_cellCfgCnt = 0;
+  static bool m_use_threads;
 };
 
 //! Sets the configuration's "printing" flag until this class is left.
@@ -1268,7 +1265,7 @@ public:
       m_configuration = configuration;
       m_configuration->SetPrinting(true);
     }
-  ~Printing()
+  virtual ~Printing()
     {
       m_configuration->SetPrinting(false);
     }
@@ -1285,7 +1282,7 @@ public:
       m_configuration = configuration;
       m_configuration->ClipToDrawRegion(false);
     }
-  ~NoClipToDrawRegion()
+  virtual ~NoClipToDrawRegion()
     {
       m_configuration->ClipToDrawRegion(true);
     }
