@@ -70,20 +70,20 @@
  */
 template <typename Enum, typename Storage, Enum defaultValue = Enum{},
   typename std::enable_if<std::is_enum<Enum>::value &&
-			  std::is_integral<Storage>::value,
-			  bool>::type = true>
+                          std::is_integral<Storage>::value,
+                          bool>::type = true>
   class EnumWrapper {
     Storage value = Storage(defaultValue);
 
     // We can at least make sure that the default value fits
     static_assert(
-		  Enum(Storage(defaultValue)) == defaultValue,
-		  "The default value doesn't survive a roundtrip through this wrapper.");
+                  Enum(Storage(defaultValue)) == defaultValue,
+                  "The default value doesn't survive a roundtrip through this wrapper.");
     // There's no point in using this type if it doesn't save space.
     static_assert(
-		  sizeof(Storage) < sizeof(Enum),
-		  "EnumWrapper should be used only to save space."
-		  "When removing it, don't forget to take care of default value!");
+                  sizeof(Storage) < sizeof(Enum),
+                  "EnumWrapper should be used only to save space."
+                  "When removing it, don't forget to take care of default value!");
 
   public:
     constexpr EnumWrapper() = default;
@@ -92,7 +92,7 @@ template <typename Enum, typename Storage, Enum defaultValue = Enum{},
     constexpr EnumWrapper(Enum value) noexcept : value(value) {}
     constexpr operator Enum() const noexcept { return Enum(value); }
     constexpr operator Storage() const = delete;
-    constexpr size_t hash() const { return std::hash<Storage>()(value); }
+    constexpr std::size_t hash() const { return std::hash<Storage>()(value); }
 
     constexpr bool operator==(EnumWrapper o) const { return value == o.value;  }
     constexpr bool operator==(Enum o) const { return value == o;  }
