@@ -310,6 +310,7 @@ const wxWindowIDRef EventIDs::menu_opsubst(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_jumptoerror(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_1D_ASCII(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_2D_ASCII(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_math_as_2D_UNICODE(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_math_as_graphics(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::internalRepresentation(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::wxMathML(wxWindow::NewControlId());
@@ -526,6 +527,7 @@ const wxWindowIDRef EventIDs::menu_format_title(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_format_image(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_format_pagebreak(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tutorials(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_help_demo_for_command(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tutorials_start(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_solving(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_casvsprogramming(wxWindow::NewControlId());
@@ -538,6 +540,8 @@ const wxWindowIDRef EventIDs::menu_help_3d(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_varnames(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_fittingData(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_help_tutorials_end(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_regex_isRegex(wxWindow::NewControlId());
+const wxWindowIDRef EventIDs::menu_regex_isTextSearch(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_history_previous(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_history_next(wxWindow::NewControlId());
 const wxWindowIDRef EventIDs::menu_check_updates(wxWindow::NewControlId());
