@@ -374,6 +374,7 @@ public:
   static const wxWindowIDRef menu_jumptoerror;
   static const wxWindowIDRef menu_math_as_1D_ASCII;
   static const wxWindowIDRef menu_math_as_2D_ASCII;
+  static const wxWindowIDRef menu_math_as_2D_UNICODE;
   static const wxWindowIDRef menu_math_as_graphics;
   static const wxWindowIDRef internalRepresentation;
   static const wxWindowIDRef wxMathML;
@@ -593,6 +594,9 @@ public:
   static const wxWindowIDRef menu_format_title;
   static const wxWindowIDRef menu_format_image;
   static const wxWindowIDRef menu_format_pagebreak;
+  static const wxWindowIDRef menu_regex_isRegex;
+  static const wxWindowIDRef menu_regex_isTextSearch;
+  static const wxWindowIDRef menu_help_demo_for_command;
   static const wxWindowIDRef menu_help_tutorials;
   static const wxWindowIDRef menu_help_tutorials_start; //! Start of bundled tutorials
   static const wxWindowIDRef menu_help_solving;
