@@ -62,7 +62,7 @@ public:
   MathParser(const MathParser&) = delete;
   //! This class doesn't have a = operator
   MathParser& operator=(const MathParser&) = delete;
-  ~MathParser();
+  virtual ~MathParser();
 
   void SetUserLabel(wxString label){ m_userDefinedLabel = label; }
   /***
@@ -70,6 +70,7 @@ public:
    * Put the result in line.
    */
   std::unique_ptr<Cell> ParseLine(wxString s, CellType style = MC_TYPE_DEFAULT);
+  std::unique_ptr<Cell> ParseLine(const wxXmlDocument &xml, CellType style = MC_TYPE_DEFAULT);
   /***
    * Parse the node and return the corresponding tag.
    */
@@ -87,13 +88,8 @@ private:
   //! A pointer to a method that handles an XML tag for a type of GroupCell
   using GroupCellFunc = std::unique_ptr<GroupCell> (MathParser::*)(wxXmlNode *node);
 
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, MathCellFunc> MathCellFunctionHash;
-  typedef std::unordered_map <wxString, GroupCellFunc> GroupCellFunctionHash;
-#else
-  WX_DECLARE_STRING_HASH_MAP(MathCellFunc, MathCellFunctionHash);
-  WX_DECLARE_STRING_HASH_MAP(GroupCellFunc, GroupCellFunctionHash);
-#endif
+  typedef std::unordered_map <wxString, MathCellFunc, wxStringHash> MathCellFunctionHash;
+  typedef std::unordered_map <wxString, GroupCellFunc, wxStringHash> GroupCellFunctionHash;
 
   //! Who you gonna call if you encounter any of these math cell tags?
   static MathCellFunctionHash m_innerTags;
