@@ -30,7 +30,7 @@
 #include <wx/string.h>
 #include <wx/arrstr.h>
 #include "precomp.h"
-#include "TextStyle.h"
+#include "cells/TextStyle.h"
 #include "Configuration.h"
 #include <unordered_map>
 
@@ -113,11 +113,7 @@ protected:
 
   Configuration *m_configuration;
 
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, int> StringHash;
-#else
-  WX_DECLARE_STRING_HASH_MAP(int, StringHash);
-#endif
+  typedef std::unordered_map <wxString, int, wxStringHash> StringHash;
   /*! Names of functions that don't require parenthesis
 
     The maxima parser automatically parses everything that is followed by
