@@ -88,19 +88,19 @@ namespace wxm {
 
   // String normalization
 
-  void NormalizeEOLsRemoveNULs(wxString &str) {
+  void NormalizeEOLsRemoveNULs(wxString *str) {
     using std::swap;
     wxString normalized;
-    normalized.reserve(str.size());
+    normalized.reserve(str->size());
 
     // Clean up the output from zeroes, and normalize the line endings
     wxStringCharType prevCh = {};
-    for (auto const ch : const_cast<const wxString &>(str)) {
+    for (auto const ch : const_cast<const wxString &>(*str)) {
       if (ch == '\0') {                          /* "\0" -> "" */
       } else if (prevCh == '\r' && ch != '\n') { /* "\r[^\n]" -> "\n" */
-	normalized += '\n';
+        normalized += '\n';
       } else if (ch != '\r') {
-	normalized += ch;
+        normalized += ch;
       }
       prevCh = ch;
     }
@@ -108,7 +108,7 @@ namespace wxm {
       normalized += '\n';
     }
 
-    swap(str, normalized);
+    swap(*str, normalized);
   }
 
 } // namespace wxm
