@@ -45,7 +45,7 @@ public:
   SvgBitmap(wxWindow *window, const unsigned char *data, const size_t len, int width = 640, int height = 480);
   SvgBitmap(wxWindow *window, const unsigned char *data, const std::size_t len, wxSize siz);
   SvgBitmap(wxWindow *window, const wxString data, wxSize siz);
-  ~SvgBitmap() override;
+  virtual ~SvgBitmap() override;
   SvgBitmap(SvgBitmap &&) = delete;
   SvgBitmap &operator=(SvgBitmap &&o) noexcept;
 
