@@ -40,6 +40,7 @@
 #include <wx/txtstrm.h>
 #include <wx/wfstream.h>
 #include <wx/zstream.h>
+#include <algorithm>
 
 #if wxCHECK_VERSION(3, 1, 0)
 #define TOOLBAR_ICON_SCALE (0.25)
@@ -65,9 +66,9 @@ wxSize ToolBar::GetOptimalBitmapSize()
 
 #if defined __WXOSX__
   int targetSize =
-    wxMax(m_ppi.x, 75) * TOOLBAR_ICON_SCALE * GetContentScaleFactor();
+    std::max(m_ppi.x, 75) * TOOLBAR_ICON_SCALE * GetContentScaleFactor();
 #else
-  int targetSize = wxMax(m_ppi.x, 75) * TOOLBAR_ICON_SCALE;
+  int targetSize = std::max(m_ppi.x, 75) * TOOLBAR_ICON_SCALE;
 #endif
   int sizeA = 128 << 4;
   while (sizeA * 3 / 2 > targetSize && sizeA >= 32) {
@@ -103,15 +104,17 @@ void ToolBar::UpdateSlider(AnimationCell *cell) {
       m_plotSlider->SetRange(0, cell->Length() - 1);
       m_plotSlider->SetValue(cell->GetDisplayedIndex());
       m_plotSlider->SetToolTip(wxString::Format(
-						_("Frame %i of %i"), cell->GetDisplayedIndex() + 1, cell->Length()));
+                                                _("Frame %li of %li"),
+                                                static_cast<long>(cell->GetDisplayedIndex()) + 1,
+                                                static_cast<long>(cell->Length())));
     }
   }
 }
 
 ToolBar::ToolBar(wxWindow *parent)
   : wxAuiToolBar(parent, -1, wxDefaultPosition, wxDefaultSize,
-		 wxAUI_TB_OVERFLOW | wxAUI_TB_PLAIN_BACKGROUND |
-		 wxAUI_TB_HORIZONTAL),
+                 wxAUI_TB_OVERFLOW | wxAUI_TB_PLAIN_BACKGROUND |
+                 wxAUI_TB_HORIZONTAL),
     m_defaultCellStyle(GC_TYPE_CODE),
     m_canCopy_old(true),
     m_canCut_old(true),
@@ -121,7 +124,7 @@ ToolBar::ToolBar(wxWindow *parent)
     m_canEvalThisCell_old(true),
     m_worksheetEmpty_old(false)
 {
-  m_svgRast.reset(nsvgCreateRasterizer());
+  m_svgRast.reset(wxm_nsvgCreateRasterizer());
 
   m_needsInformation = false;
   m_AnimationStartStopState = Inactive;
@@ -206,10 +209,10 @@ void ToolBar::AddTools() {
             "the button left to this one."));
   int bitmapWidth = GetOptimalBitmapSize().x;
   m_followIcon = ArtProvider::GetImage(this, wxS("arrow_up_square"), bitmapWidth, ARROW_UP_SQUARE_SVG_GZ,
-				       ARROW_UP_SQUARE_SVG_GZ_SIZE);
+                                       ARROW_UP_SQUARE_SVG_GZ_SIZE);
   m_needsInformationIcon =
     ArtProvider::GetImage(this, wxS("software-update-urgent"), bitmapWidth, SOFTWARE_UPDATE_URGENT_SVG_GZ,
-	      SOFTWARE_UPDATE_URGENT_SVG_GZ_SIZE);
+                          SOFTWARE_UPDATE_URGENT_SVG_GZ_SIZE);
   AddTool(tb_follow, _("Follow"), m_followIcon,
           _("Return to the cell that is currently being evaluated"));
   EnableTool(tb_follow, false);
@@ -225,8 +228,8 @@ void ToolBar::AddTools() {
           _("Send all cells to maxima"));
 
   AddTool(
-	  tb_evaltillhere, _("Evaluate to point"), GetEvalTillHereBitmap(bitmapSize),
-	  _("Evaluate the file from its beginning to the cell above the cursor"));
+          tb_evaltillhere, _("Evaluate to point"), GetEvalTillHereBitmap(bitmapSize),
+          _("Evaluate the file from its beginning to the cell above the cursor"));
 
   AddTool(tb_evaluate_rest, _("Evaluate the rest"), GetEvalRestBitmap(bitmapSize),
           _("Evaluate the file from the cursor to its end"));
@@ -255,24 +258,24 @@ void ToolBar::AddTools() {
   m_textStyle = new wxChoice(this, tb_changeStyle, wxDefaultPosition,
                              wxDefaultSize, textStyle);
   m_textStyle->SetToolTip(
-			  _("For faster creation of cells the following shortcuts exist:\n\n"
-			    "   Ctrl+0: Math cell\n"
-			    "   Ctrl+1: Text cell\n"
-			    "   Ctrl+2: Title cell\n"
-			    "   Ctrl+3: Section cell\n"
-			    "   Ctrl+4: Subsection cell\n"
-			    "   Ctrl+5: Sub-Subsection cell\n"
-			    "   Ctrl+6: Heading5 cell\n"
-			    "   Ctrl+7: Heading6 cell\n"));
+                          _("For faster creation of cells the following shortcuts exist:\n\n"
+                            "   Ctrl+0: Math cell\n"
+                            "   Ctrl+1: Text cell\n"
+                            "   Ctrl+2: Title cell\n"
+                            "   Ctrl+3: Section cell\n"
+                            "   Ctrl+4: Subsection cell\n"
+                            "   Ctrl+5: Sub-Subsection cell\n"
+                            "   Ctrl+6: Heading5 cell\n"
+                            "   Ctrl+7: Heading6 cell\n"));
   m_textStyle->SetSelection(textStyleSelection);
   AddControl(m_textStyle);
 
   m_PlayButton =
     ArtProvider::GetImage(this, wxS("media-playback-start"), bitmapWidth, MEDIA_PLAYBACK_START_SVG_GZ,
-	      MEDIA_PLAYBACK_START_SVG_GZ_SIZE);
+                          MEDIA_PLAYBACK_START_SVG_GZ_SIZE);
   m_StopButton =
     ArtProvider::GetImage(this, wxS("media-playback-stop"), bitmapWidth, MEDIA_PLAYBACK_STOP_SVG_GZ,
-	      MEDIA_PLAYBACK_STOP_SVG_GZ_SIZE);
+                          MEDIA_PLAYBACK_STOP_SVG_GZ_SIZE);
 
   // It felt like a good idea to combine the play and the stop button.
   AddTool(tb_animation_startStop, _("Start or Stop animation"), m_PlayButton,
@@ -282,17 +285,17 @@ void ToolBar::AddTools() {
 
   m_ppi = GetPPI();
 
-  int sliderWidth = wxMax(m_ppi.x, 75) * 200 / 72;
+  int sliderWidth = std::max(m_ppi.x, 75) * 200 / 72;
   int width, height;
   wxDisplaySize(&width, &height);
   if (width < 800)
-    sliderWidth = wxMin(sliderWidth, 100);
+    sliderWidth = std::min(sliderWidth, 100);
   wxDELETE(m_plotSlider);
   m_plotSlider = new wxSlider(this, plot_slider_id, 0, 0, 10, wxDefaultPosition,
                               wxSize(sliderWidth, -1), wxSL_HORIZONTAL);
   m_plotSlider->SetToolTip(
-			   _("After clicking on animations created with with_slider_draw() or "
-			     "similar this slider allows to change the current frame."));
+                           _("After clicking on animations created with with_slider_draw() or "
+                             "similar this slider allows to change the current frame."));
   m_plotSlider->Enable(false);
   m_animationMaxIndex = -1;
   m_animationDisplayedIndex = -1;
@@ -316,15 +319,15 @@ wxSize ToolBar::GetPPI()
   else
     ppi = wxDisplay(display_idx).GetPPI();
 #else
-    m_ppi = wxGetDisplayPPI();
-#endif  
+  m_ppi = wxGetDisplayPPI();
+#endif
   if ((ppi.x <= 10) || (ppi.y <= 10))
     ppi = wxSize(72, 72);
   return ppi;
-}  
+}
 
 void ToolBar::UpdateBitmaps() {
-  wxSize bitmapSize = GetOptimalBitmapSize(); 
+  wxSize bitmapSize = GetOptimalBitmapSize();
   SetToolBitmapSize(bitmapSize);
   int bitmapWidth = bitmapSize.x;
 
@@ -332,9 +335,9 @@ void ToolBar::UpdateBitmaps() {
   if ((ppi.x == m_ppi.x) && (ppi.y == m_ppi.y))
     return;
   wxLogMessage(_("Display resolution according to wxWidgets: %li x %li ppi"),
-	       (long)ppi.x,
-	       (long)ppi.y);
-  
+               static_cast<long>(ppi.x),
+               static_cast<long>(ppi.y));
+
   m_ppi = ppi;
 
   SetToolBitmap(tb_eval, GetEvalBitmap(bitmapSize));
@@ -353,21 +356,21 @@ void ToolBar::UpdateBitmaps() {
   SetToolBitmap(wxID_FIND, GetFindBitmap(bitmapSize));
   SetToolBitmap(menu_restart_id, GetRestartBitmap(bitmapSize));
   SetToolBitmap(tb_interrupt, GetInterruptBitmap(bitmapSize));
-  m_followIcon = ArtProvider::GetImage(this, wxS("arrow_up_square"), bitmapWidth, ARROW_UP_SQUARE_SVG_GZ, 
-                           ARROW_UP_SQUARE_SVG_GZ_SIZE);
+  m_followIcon = ArtProvider::GetImage(this, wxS("arrow_up_square"), bitmapWidth, ARROW_UP_SQUARE_SVG_GZ,
+                                       ARROW_UP_SQUARE_SVG_GZ_SIZE);
   m_needsInformationIcon =
     ArtProvider::GetImage(this, wxS("software-update-urgent"), bitmapWidth, SOFTWARE_UPDATE_URGENT_SVG_GZ,
-	      SOFTWARE_UPDATE_URGENT_SVG_GZ_SIZE);
+                          SOFTWARE_UPDATE_URGENT_SVG_GZ_SIZE);
   SetToolBitmap(tb_follow, m_followIcon);
   SetToolBitmap(tb_evaltillhere, GetEvalTillHereBitmap(bitmapSize));
   SetToolBitmap(tb_evaluate_rest, GetEvalRestBitmap(bitmapSize));
   SetToolBitmap(tb_hideCode, GetHideCodeBitmap(bitmapSize));
   m_PlayButton =
     ArtProvider::GetImage(this, wxS("media-playback-start"), bitmapWidth, MEDIA_PLAYBACK_START_SVG_GZ,
-	      MEDIA_PLAYBACK_START_SVG_GZ_SIZE);
+                          MEDIA_PLAYBACK_START_SVG_GZ_SIZE);
   m_StopButton =
     ArtProvider::GetImage(this, wxS("media-playback-stop"), bitmapWidth, MEDIA_PLAYBACK_STOP_SVG_GZ,
-	      MEDIA_PLAYBACK_STOP_SVG_GZ_SIZE);
+                          MEDIA_PLAYBACK_STOP_SVG_GZ_SIZE);
   SetToolBitmap(tb_animation_startStop, m_PlayButton);
   SetToolBitmap(wxID_HELP, GetHelpBitmap(bitmapSize));
   Realize();
@@ -400,7 +403,7 @@ wxBitmap ToolBar::GetRedoBitmap(wxSize siz) {
 }
 wxBitmap ToolBar::GetPreferencesBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("gtk-preferences"), siz.x, GTK_PREFERENCES_SVG_GZ,
-                   GTK_PREFERENCES_SVG_GZ_SIZE);
+                               GTK_PREFERENCES_SVG_GZ_SIZE);
 }
 wxBitmap ToolBar::GetCutBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("gtk-cut"), siz.x, GTK_CUT_SVG_GZ, GTK_CUT_SVG_GZ_SIZE);
@@ -413,14 +416,14 @@ wxBitmap ToolBar::GetPasteBitmap(wxSize siz) {
 }
 wxBitmap ToolBar::GetSelectAllBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("gtk-select-all"), siz.x, GTK_SELECT_ALL_SVG_GZ,
-                   GTK_SELECT_ALL_SVG_GZ_SIZE);
+                               GTK_SELECT_ALL_SVG_GZ_SIZE);
 }
 wxBitmap ToolBar::GetFindBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("gtk-find"), siz.x, GTK_FIND_SVG_GZ, GTK_FIND_SVG_GZ_SIZE);
 }
 wxBitmap ToolBar::GetRestartBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("view-refresh"), siz.x, VIEW_REFRESH1_SVG_GZ,
-                   VIEW_REFRESH1_SVG_GZ_SIZE);
+                               VIEW_REFRESH1_SVG_GZ_SIZE);
 }
 wxBitmap ToolBar::GetInterruptBitmap(wxSize siz) {
   return ArtProvider::GetImage(this, wxS("gtk-stop"), siz.x, GTK_STOP_SVG_GZ, GTK_STOP_SVG_GZ_SIZE);
@@ -560,8 +563,8 @@ void ToolBar::AnimationButtonState(AnimationStartStopState state) {
       EnableTool(tb_animation_startStop, false);
       m_plotSlider->Enable(false);
       m_plotSlider->SetToolTip(
-			       _("After clicking on animations created with with_slider_draw() or "
-				 "similar this slider allows to change the current frame."));
+                               _("After clicking on animations created with with_slider_draw() or "
+                                 "similar this slider allows to change the current frame."));
       m_animationMaxIndex = -1;
       m_animationDisplayedIndex = -1;
 
