@@ -41,7 +41,6 @@
 #include <wx/textfile.h>
 #include <wx/fdrepdlg.h>
 #include <wx/dc.h>
-#include <thread>
 #include <vector>
 #include <utility>
 #include <memory>
@@ -54,14 +53,13 @@
 #include "cells/GroupCell.h"
 #include "cells/TextCell.h"
 #include "EvaluationQueue.h"
-#include "FindReplaceDialog.h"
+#include "dialogs/FindReplaceDialog.h"
 #include "Autocomplete.h"
 #include "AutocompletePopup.h"
 #include "sidebars/TableOfContents.h"
 #include "sidebars/UnicodeSidebar.h"
 #include "ToolBar.h"
 #include <thread>
-#include <vector>
 
 /*! The canvas that contains the spreadsheet the whole program is about.
 
@@ -686,7 +684,7 @@ public:
   //! Is called if this element looses or gets the focus
   void OnActivate(wxActivateEvent &event);
 private:
-  std::vector<std::thread> m_drawThreads;
+//  std::vector<std::thread> m_drawThreads;
   static std::mutex m_drawDCLock;
   /*! The pointer to thesettings storage
    */
@@ -856,7 +854,7 @@ public:
             bool reactToEvents = true);
 
   //! The destructor
-  ~Worksheet();
+  virtual ~Worksheet();
 
   //! The timer that tells us when the keyboard is inactive so an autosave isn't disrupting
   wxTimer m_keyboardInactiveTimer;
@@ -1465,6 +1463,9 @@ public:
   //! Add a xml-encoded list of symbols to the autocompletion list
   void AddSymbols(wxString xml)
     { m_autocomplete.AddSymbols(xml); }
+  //! Add a xml-encoded list of symbols to the autocompletion list
+  void AddSymbols(wxXmlDocument xml)
+    { m_autocomplete.AddSymbols(xml); }
 
   void SetActiveCellText(const wxString &text);
 
@@ -1537,7 +1538,7 @@ public:
   wxString GetHelpfileURL(wxString keyword)
     {return m_maximaManual.GetHelpfileURL(keyword);}
   //! The panel the user can display variable contents in
-  Variablespane *m_variablesPane;
+  Variablespane *m_variablesPane = NULL;
 
   //! Returns the index in (%i...) or (%o...)
   int GetCellIndex(Cell *cell) const;
