@@ -24,7 +24,7 @@
 /*! \file
   This file declares the class AbsCell
 
-  AbsCell is the Cell type that represents the field that represents the 
+  AbsCell is the Cell type that represents the field that represents the
   <code>abs()</code> and <code>cabs()</code> commands.
 */
 
@@ -35,22 +35,22 @@
 #include <memory>
 
 /*! \file
-  
+
   This file defines the class for the cell type that represents an abs(x) block.
 */
 
 /*! A cell that represents an abs(x) block
-  
+
   In the case that this cell is broken into multiple lines, it is
   represented by the following cells in the draw order:
-  
+
   - The AbsCell itself
   - The opening "abs("
   - The contents
   - The closing ")".
-   
+
   If it isn't broken into multiple cells, then m_nextToDraw points to the
-  cell that follows this AbsCell.  
+  cell that follows this AbsCell.
 */
 class AbsCell final : public Cell
 {
@@ -60,12 +60,12 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 3; }
+  size_t GetInnerCellCount() const override { return 3; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   bool BreakUp() override;
-  
+
   void Recalculate(AFontSize fontsize) override;
 
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
@@ -78,7 +78,7 @@ public:
   wxString ToXML() const override;
 
   void SetNextToDraw(Cell *next) override;
-  
+
 private:
   void MakeBreakupCells();
 
@@ -95,7 +95,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_AbsCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
