@@ -295,7 +295,7 @@ int Cell::GetLineWidth() const {
 /*! Draw this cell to dc
 
   To make this work each derived class must draw the content of the cell
-  and then call MathCall::Draw(...).
+  and then call MathCell::Draw(...).
 */
 void Cell::Draw(wxPoint point, wxDC *dc, wxDC *WXUNUSED(antialiassingDC)) {
   if(m_configuration->GetDebugmode())
@@ -304,7 +304,6 @@ void Cell::Draw(wxPoint point, wxDC *dc, wxDC *WXUNUSED(antialiassingDC)) {
         {
           wxASSERT(m_width  >= 0);
           wxASSERT(m_height >= 0);
-          wxASSERT(m_center >= 0);
         }
     }
   m_configuration->NotifyOfCellRedraw(this);
@@ -1427,6 +1426,14 @@ wxAccStatus Cell::GetRole(int WXUNUSED(childId), wxAccRole *role) const {
 
 #endif
 
+size_t Cell::GetInnerCellCount_recursive() const
+{
+  size_t retval = GetInnerCellCount();
+  for (const Cell &cell : OnInner(this))
+    retval += cell.GetInnerCellCount_recursive();
+  return retval;
+}
+
 size_t Cell::GetInnerCellCount() const { return 0; }
 
 Cell *Cell::GetInnerCell(size_t) const {
