@@ -79,7 +79,7 @@ public:
     {
       T *ptr = dynamic_cast<T *>(m_head.get());
       if (ptr) {
-        m_head.release();
+        (void) m_head.release();
         m_tail = {};
         m_lastAppended = {};
       } else
@@ -96,7 +96,7 @@ public:
       m_lastAppended = {};
       auto retval = dynamic_unique_ptr_cast<T>(std::move(m_head));
 
-      wxASSERT(!m_head && !m_tail && !m_lastAppended);
+      wxASSERT(!m_tail && !m_lastAppended);
       return retval;
     }
 
@@ -119,8 +119,8 @@ public:
   //! appended.
   T *DynamicAppend(Cell *cells)
     {
-      return static_cast<T *>(
-        base_DynamicAppend(std::unique_ptr<Cell>(cells), DynamicCast));
+      return std::move(static_cast<T *>(
+                         base_DynamicAppend(std::unique_ptr<Cell>(cells), DynamicCast)));
     }
 
   //! Appends one or more cells if they are all of the correct type, otherwise
@@ -146,7 +146,7 @@ public:
   //! Checks the integrity of the list pointers of the given cell in relation to
   //! its neighbors.
   static void Check(const Cell *cell);
-  static void Check(const GroupCell *cell);
+  static void Check(const GroupCell *c);
 
   /*! Replaces the successor of a given cell, and returns the old one (if any).
    *
