@@ -35,9 +35,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 5; }
+  size_t GetInnerCellCount() const override { return 5; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -69,7 +69,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_DiffCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
