@@ -626,11 +626,7 @@ private:
 
 //** Large fields
 //**
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, wxSize> StringHash;
-#else
-  WX_DECLARE_STRING_HASH_MAP(wxSize, StringHash);
-#endif
+  typedef std::unordered_map <wxString, wxSize, wxStringHash> StringHash;
   //! Cached widths of text snippets, one width per style
   StringHash m_widths;
 
