@@ -36,16 +36,16 @@
 /*! This cell represents a exp() or %e^x-construct.
 
   In the case that this cell is broken into two lines in the order of
-  m_nextToDraw this cell is represented by the following individual 
+  m_nextToDraw this cell is represented by the following individual
   cells:
-  
+
   - The ExptCell itself
   - The opening "exp("
   - The contents
   - The closing ")".
-   
-  If it isn't broken into multiple cells m_nextToDraw points to the 
-  cell that follows this Cell. 
+
+  If it isn't broken into multiple cells m_nextToDraw points to the
+  cell that follows this Cell.
 */
 class ExptCell final : public Cell
 {
@@ -55,13 +55,13 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 5; }
+  size_t GetInnerCellCount() const override { return 5; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_baseCell)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_baseCell)[index].get(); }
 
   //! By how much do we want to rise the power?
   double PowRise() const {return .3 * m_fontSize_Scaled;}
-  
+
   void Recalculate(AFontSize fontsize) override;
 
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
@@ -102,12 +102,12 @@ private:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_ExptCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_isMatrix = false;
     }
-  bool m_isMatrix : 1 /* InitBitFields */;
+  bool m_isMatrix : 1 /* InitBitFields_ExptCell */;
 };
 
 
