@@ -84,53 +84,54 @@ void FracCell::MakeDivideCell() {
 }
 
 void FracCell::Recalculate(AFontSize fontsize) {
-  if (m_inExponent || IsBrokenIntoLines()) {
-    m_displayedNum->RecalculateList(fontsize);
-    m_displayedDenom->RecalculateList(fontsize);
-    m_divide->RecalculateList(fontsize);
-  } else {
-    m_displayedNum->RecalculateList({MC_MIN_SIZE, fontsize - FRAC_DEC});
-    m_displayedDenom->RecalculateList({MC_MIN_SIZE, fontsize - FRAC_DEC});
-  }
-
-  if (IsBrokenIntoLines()) {
-    m_height = 0;
-    m_center = 0;
-    m_width = 0;
-  } else {
-    if (m_inExponent) {
-      m_protrusion = m_horizontalGapLeft = m_horizontalGapRight = 0;
-      m_width = Num()->GetWidth() + Denom()->GetWidth() + m_divide->GetWidth();
-      m_height = std::max(Num()->GetHeightList(), Denom()->GetHeightList()) +
-        Scale_Px(6.5);
-      m_center =
-        std::max(Num()->GetCenterList(), Denom()->GetCenterList()) + Scale_Px(3);
+  if (NeedsRecalculation(fontsize)) {
+    if (m_inExponent || IsBrokenIntoLines()) {
+      m_displayedNum->RecalculateList(fontsize);
+      m_displayedDenom->RecalculateList(fontsize);
+      m_divide->RecalculateList(fontsize);
     } else {
-      m_protrusion = Scale_Px(m_configuration->GetMathFontSize() / 2);
-
-      // We want half a space's widh of blank space to separate us from the
-      // next minus.
-
-      if (GetPrevious() && GetPrevious()->ToString().EndsWith(wxS("-")))
-        m_horizontalGapLeft = m_protrusion;
-      else
-        m_horizontalGapLeft = 0;
-
-      if (GetNext() && GetNext()->ToString().StartsWith(wxS("-")))
-        m_horizontalGapRight = m_protrusion;
-      else
-        m_horizontalGapRight = 0;
-
-      m_width = std::max(m_displayedNum->GetFullWidth(),
-                      m_displayedDenom->GetFullWidth()) +
-        2 * m_protrusion + m_horizontalGapLeft + m_horizontalGapRight;
-      m_height =
-        Num()->GetHeightList() + Denom()->GetHeightList() + Scale_Px(6.5);
-      m_center = Num()->GetHeightList() + Scale_Px(3);
+      m_displayedNum->RecalculateList({MC_MIN_SIZE, fontsize - FRAC_DEC});
+      m_displayedDenom->RecalculateList({MC_MIN_SIZE, fontsize - FRAC_DEC});
     }
-  }
 
-  Cell::Recalculate(fontsize);
+    if (IsBrokenIntoLines()) {
+      m_height = 0;
+      m_center = 0;
+      m_width = 0;
+    } else {
+      if (m_inExponent) {
+        m_protrusion = m_horizontalGapLeft = m_horizontalGapRight = 0;
+        m_width = Num()->GetWidth() + Denom()->GetWidth() + m_divide->GetWidth();
+        m_height = std::max(Num()->GetHeightList(), Denom()->GetHeightList()) +
+          Scale_Px(6.5);
+        m_center =
+          std::max(Num()->GetCenterList(), Denom()->GetCenterList()) + Scale_Px(3);
+      } else {
+        m_protrusion = Scale_Px(m_configuration->GetMathFontSize() / 2);
+
+        // We want half a space's widh of blank space to separate us from the
+        // next minus.
+
+        if (GetPrevious() && GetPrevious()->ToString().EndsWith(wxS("-")))
+          m_horizontalGapLeft = m_protrusion;
+        else
+          m_horizontalGapLeft = 0;
+
+        if (GetNext() && GetNext()->ToString().StartsWith(wxS("-")))
+          m_horizontalGapRight = m_protrusion;
+        else
+          m_horizontalGapRight = 0;
+
+        m_width = std::max(m_displayedNum->GetFullWidth(),
+                           m_displayedDenom->GetFullWidth()) +
+          2 * m_protrusion + m_horizontalGapLeft + m_horizontalGapRight;
+        m_height =
+          Num()->GetHeightList() + Denom()->GetHeightList() + Scale_Px(6.5);
+        m_center = Num()->GetHeightList() + Scale_Px(3);
+      }
+    }
+    Cell::Recalculate(fontsize);
+  }
 }
 
 void FracCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
@@ -196,7 +197,7 @@ wxString FracCell::ToString() const {
       s = wxS("binomial(") + Num()->ListToString() + wxS(",") +
         Denom()->ListToString() + wxS(")");
     } else {
-      Cell *tmp = Denom();
+      const Cell *tmp = Denom();
       while (tmp != NULL) {
         tmp = tmp->GetNext(); // Skip the d
         if (tmp == NULL)
@@ -274,22 +275,24 @@ wxString FracCell::ToOMML() const {
 
 wxString FracCell::ToXML() const {
   wxString s = (m_fracStyle == FC_NORMAL || m_fracStyle == FC_DIFF)
-    ? _T("f")
-    : _T("f line = \"no\"");
+    ? wxS("")
+    : wxS(" line = \"no\"");
   wxString diffStyle;
   if (m_fracStyle == FC_DIFF)
     diffStyle = wxS(" diffstyle=\"yes\"");
   if (HasHardLineBreak())
     diffStyle += wxS(" breakline=\"true\"");
 
-  return _T("<") + s + diffStyle + _T("><r>") + Num()->ListToXML() +
-    _T("</r><r>") + Denom()->ListToXML() + _T("</r></f>");
+  return wxS("<f") + s + diffStyle + wxS("><r>") + Num()->ListToXML() +
+    wxS("</r><r>") + Denom()->ListToXML() + wxS("</r></f>");
 }
 
 void FracCell::SetIsExponent() {
   if (Num()->IsShortNum() && Denom()->IsShortNum()) {
     m_inExponent = true;
     MakeDivideCell();
+    Num()->SetIsExponentList();
+    Denom()->SetIsExponentList();
   }
 }
 
@@ -322,9 +325,6 @@ bool FracCell::BreakUp() {
   m_divide->SetNextToDraw(m_displayedDenom);
   m_displayedDenom->SetNextToDraw(m_nextToDraw);
   m_nextToDraw = m_displayedNum;
-  ResetCellListSizes();
-  m_height = 0;
-  m_center = 0;
   return true;
 }
 
