@@ -39,7 +39,7 @@
    Fractions can be drawn in 2 ways:
    - As a 2D fraction (\f$ \frac{a}{b} \f$) if the fraction is narrow enough to fit
    on the screen, or
-   - as a linear division (\f$ a/b \f$) if it doesn't. 
+   - as a linear division (\f$ a/b \f$) if it doesn't.
 */
 class FracCell final : public Cell
 {
@@ -50,9 +50,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 3; }
+  size_t GetInnerCellCount() const override { return 3; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_displayedNum)[index]; }
+  Cell *GetInnerCell(size_t index) const override { return (&m_displayedNum)[index]; }
 
   //! All types of fractions we support
   enum FracType : int8_t
@@ -66,7 +66,7 @@ public:
 
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 
-  void SetFracStyle(FracType style) { m_fracStyle = style; }
+  void SetFracStyle(FracType style);
 
   //! Answers the question if this is an operator by returning "true".
   bool IsOperator() const override { return true; }
@@ -118,15 +118,15 @@ private:
   //! How much wider should the horizontal line be on both ends than num or denom?
   int m_protrusion = 0;
   /*! The horizontal gap between this frac and any minus before it
-  
-    This gap hinders avoids the horizontal rule of a fraction from building a straight 
+
+    This gap hinders avoids the horizontal rule of a fraction from building a straight
     nearly-uninterrupted horizontal line together with a minus. It is only introduced
     if there is an actual minus.
   */
   int m_horizontalGapLeft = 0;
   /*! The horizontal gap between this frac and any minus that follows it
-  
-    This gap hinders avoids the horizontal rule of a fraction from building a straight 
+
+    This gap hinders avoids the horizontal rule of a fraction from building a straight
     nearly-uninterrupted horizontal line together with a minus. It is only introduced
     if there is an actual minus.
   */
@@ -137,13 +137,13 @@ private:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_FracCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_inExponent = false;
     }
   //! Fractions in exponents are shown in their linear form.
-  bool m_inExponent : 1 /* InitBitFields */;
+  bool m_inExponent : 1 /* InitBitFields_FracCell */;
 };
 
 #endif // FRACCELL_H
