@@ -54,19 +54,21 @@ FunCell::FunCell(GroupCell *group, const FunCell &cell)
 DEFINE_CELL(FunCell)
 
 void FunCell::Recalculate(AFontSize fontsize) {
-  m_argCell->RecalculateList(fontsize);
-  m_nameCell->RecalculateList(fontsize);
+  if (NeedsRecalculation(fontsize)) {
+    m_argCell->RecalculateList(fontsize);
+    m_nameCell->RecalculateList(fontsize);
 
-  if (IsBrokenIntoLines()) {
-    m_width = m_center = m_height = 0;
-  } else {
-    m_width =
-      m_nameCell->GetFullWidth() + m_argCell->GetFullWidth() - Scale_Px(1);
-    m_center = std::max(m_nameCell->GetCenterList(), m_argCell->GetCenterList());
-    m_height =
-      m_center + std::max(m_nameCell->GetMaxDrop(), m_argCell->GetMaxDrop());
+    if (IsBrokenIntoLines()) {
+      m_width = m_center = m_height = 0;
+    } else {
+      m_width =
+        m_nameCell->GetFullWidth() + m_argCell->GetFullWidth() - Scale_Px(1);
+      m_center = std::max(m_nameCell->GetCenterList(), m_argCell->GetCenterList());
+      m_height =
+        m_center + std::max(m_nameCell->GetMaxDrop(), m_argCell->GetMaxDrop());
+    }
+    Cell::Recalculate(fontsize);
   }
-  Cell::Recalculate(fontsize);
 }
 
 void FunCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
@@ -133,8 +135,6 @@ wxString FunCell::ToTeX() const {
 }
 
 wxString FunCell::ToXML() const {
-  //  if (IsBrokenIntoLines())
-  //    return wxEmptyString;
   wxString flags;
   if (HasHardLineBreak())
     flags += wxS(" breakline=\"true\"");
@@ -161,9 +161,6 @@ bool FunCell::BreakUp() {
   m_nameCell->last()->SetNextToDraw(m_argCell);
   m_argCell->last()->SetNextToDraw(m_nextToDraw);
   m_nextToDraw = m_nameCell;
-  ResetCellListSizes();
-  m_height = 0;
-  m_center = 0;
   return true;
 }
 
