@@ -39,16 +39,16 @@
   - ConjugateCell
 
   In the case that this cell is broken into two lines in the order of
-  m_nextToDraw this cell is represented by the following individual 
+  m_nextToDraw this cell is represented by the following individual
   cells:
-  
+
   - The FunCell itself
   - The function name"
   - The ParenCell containing its contents
   - The closing ")".
-   
-  If it isn't broken into multiple cells m_nextToDraw points to the 
-  cell that follows this Cell. 
+
+  If it isn't broken into multiple cells m_nextToDraw points to the
+  cell that follows this Cell.
 */
 class FunCell final : public Cell
 {
@@ -59,9 +59,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 2; }
+  size_t GetInnerCellCount() const override { return 2; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_nameCell)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_nameCell)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -94,7 +94,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_FunCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
