@@ -50,12 +50,6 @@
 #include <wx/config.h>
 #include <clocale>
 
-#ifdef __WINDOWS__
-constexpr bool TEMPORARY_WINDOWS_PERFORMANCE_HACK = true;
-#else
-constexpr bool TEMPORARY_WINDOWS_PERFORMANCE_HACK = false;
-#endif
-
 #if wxUSE_ACCESSIBILITY
 // TODO This class is not used anywhere.
 class HCaretCell : public wxAccessible {
@@ -1016,23 +1010,25 @@ wxString GroupCell::ToTeX(wxString imgDir, wxString filename,
       (*imgCounter)++;
       wxString image = filename + wxString::Format(wxS("_%d"), *imgCounter);
       wxString file;
-      if(imgCopy)
-        file = imgDir + wxS("/") + image + wxS(".") + imgCopy->GetExtension();
 
       if (!wxDirExists(imgDir))
         wxMkdir(imgDir);
 
-      if (imgCopy->ToImageFile(file).x >= 0) {
-        str << wxS("\\begin{figure}[htb]\n") << wxS("  \\centering\n")
+      if(imgCopy)
+        {
+          file = imgDir + wxS("/") + image + wxS(".") + imgCopy->GetExtension();
+          if (imgCopy->ToImageFile(file).x >= 0) {
+            str << wxS("\\begin{figure}[htb]\n") << wxS("  \\centering\n")
             << wxS("    \\includeimage{") << filename << wxS("_img/") << image
             << wxS("}\n") << wxS("  \\caption{")
             << m_inputLabel->GetNext()->ToTeX().Trim() << wxS("}\n")
             << wxS("\\end{figure}\n");
-      }
+          }
+        }
     } else
       str << wxS("\n\\verb|<<GRAPHICS>>|\n");
     break;
-
+    
   case GC_TYPE_CODE:
     str = ToTeXCodeCell(imgDir, filename, imgCounter);
     str.Replace(wxS("\\[\\displaystyle \\]"), wxS(""));
@@ -1119,8 +1115,10 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename,
     bool mathMode = false;
 
     for (const Cell &tmp : OnDrawList(m_output.get())) {
-      if (tmp.GetType() == MC_TYPE_IMAGE || tmp.GetType() == MC_TYPE_SLIDE) {
+      if (tmp.GetType() == MC_TYPE_IMAGE) {
         str << ToTeXImage(&tmp, imgDir, filename, imgCounter);
+      } else if (tmp.GetType() == MC_TYPE_SLIDE) {
+        str << "\\text{[animated graphics - not shown in TeX export]}";
       } else {
         switch (tmp.GetTextStyle()) {
         case TS_LABEL:
@@ -1167,8 +1165,7 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename,
 wxString GroupCell::ToTeXImage(const Cell *tmp, wxString imgDir, wxString filename,
                                int *imgCounter) {
   wxASSERT_MSG((imgCounter != NULL), _("Bug: No image counter to write to!"));
-  if(tmp == NULL)
-    {
+  if(tmp == NULL) {
       wxLogMessage(_("No image to export"));
       return wxEmptyString;
     }
@@ -1437,7 +1434,7 @@ void GroupCell::BreakLines() {
     return;
 
   //  if (NeedsRecalculation(EditorFontSize()))
-    m_output->RecalculateList(m_configuration->GetMathFontSize());
+  m_output->RecalculateList(m_configuration->GetMathFontSize());
 
   m_output->BreakLines_List();
 }
@@ -1897,5 +1894,3 @@ std::ostream& operator<<(std::ostream& out, const GroupType grouptype){
   }
   return out << result;
 }
-
-    
