@@ -35,15 +35,15 @@
 /*! The class that represents parenthesis that are wrapped around text
 
   In the case that this cell is broken into two lines in the order of
-  m_nextToDraw this cell is represented by the following individual 
+  m_nextToDraw this cell is represented by the following individual
   cells:
-  
+
   - The ListCell itself
   - The opening "["
   - The contents
   - The closing "]".
-   
-  If it isn't broken into multiple cells m_nextToDraw points to the 
+
+  If it isn't broken into multiple cells m_nextToDraw points to the
   cell that follows this Cell.
 */
 class ListCell : public Cell
@@ -54,9 +54,9 @@ public:
   virtual std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   virtual const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 3; }
+  size_t GetInnerCellCount() const override { return 3; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -86,13 +86,13 @@ protected:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_ListCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_drawAsAscii = true;
     }
   //! How to create a big parenthesis sign?
-  bool m_drawAsAscii : 1 /* InitBitFields */;
+  bool m_drawAsAscii : 1 /* InitBitFields_ListCell */;
 };
 
 #endif // LISTCELL_H
