@@ -35,15 +35,15 @@
 /*! The class that represents parenthesis that are wrapped around text
 
   In the case that this cell is broken into two lines in the order of
-  m_nextToDraw this cell is represented by the following individual 
+  m_nextToDraw this cell is represented by the following individual
   cells:
-  
+
   - The ParenCell itself
   - The opening "("
   - The contents
   - The closing ")".
-   
-  If it isn't broken into multiple cells m_nextToDraw points to the 
+
+  If it isn't broken into multiple cells m_nextToDraw points to the
   cell that follows this Cell.
 */
 class ParenCell final : public Cell
@@ -54,9 +54,9 @@ public:
   const CellTypeInfo &GetInfo() override;
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
 
-  int GetInnerCellCount() const override { return 3; }
+  size_t GetInnerCellCount() const override { return 3; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   Cell *GetInner() const { return m_innerCell.get(); }
   void SetInner(std::unique_ptr<Cell> inner, CellType type = MC_TYPE_DEFAULT);
@@ -69,7 +69,7 @@ public:
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
 
   bool BreakUp() override;
-  
+
   wxString ToMathML() const override;
   wxString ToMatlab() const override;
   wxString ToOMML() const override;
@@ -95,12 +95,12 @@ private:
 
 //** Bitfield objects (1 bytes)
 //**
-  void InitBitFields()
+  void InitBitFields_ParenCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
       m_print = true;
     }
-  bool m_print : 1 /* InitBitFields */;
+  bool m_print : 1 /* InitBitFields_ParenCell */;
 };
 
 #endif // PARENCELL_H
