@@ -64,20 +64,22 @@ void SqrtCell::MakeBreakUpCells() {
 }
 
 void SqrtCell::Recalculate(AFontSize fontsize) {
-  m_innerCell->RecalculateList(fontsize);
-
-  m_width = m_innerCell->GetFullWidth() + Scale_Px(13) + 1;
-  if (!IsBrokenIntoLines()) {
-    auto openHeight = 0; // m_open->GetHeightList();
-    auto openCenter = 0; // m_open->GetCenterList();
-    m_height = std::max(m_innerCell->GetHeightList(), openHeight) + Scale_Px(3);
-    m_center = std::max(m_innerCell->GetCenterList(), openCenter) + Scale_Px(3);
-  } else {
-    m_height = m_center = m_width = 0;
-    m_open->Recalculate(fontsize);
-    m_close->Recalculate(fontsize);
+  if (NeedsRecalculation(fontsize)) {
+    m_innerCell->RecalculateList(fontsize);
+    
+    m_width = m_innerCell->GetFullWidth() + Scale_Px(13) + 1;
+    if (!IsBrokenIntoLines()) {
+      auto openHeight = 0; // m_open->GetHeightList();
+      auto openCenter = 0; // m_open->GetCenterList();
+      m_height = std::max(m_innerCell->GetHeightList(), openHeight) + Scale_Px(3);
+      m_center = std::max(m_innerCell->GetCenterList(), openCenter) + Scale_Px(3);
+    } else {
+      m_height = m_center = m_width = 0;
+      m_open->Recalculate(fontsize);
+      m_close->Recalculate(fontsize);
+    }
+    Cell::Recalculate(fontsize);
   }
-  Cell::Recalculate(fontsize);
 }
 
 void SqrtCell::Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) {
@@ -144,8 +146,6 @@ wxString SqrtCell::ToOMML() const {
 }
 
 wxString SqrtCell::ToXML() const {
-  //  if (IsBrokenIntoLines())
-  //    return wxEmptyString;
   wxString flags;
   if (HasHardLineBreak())
     flags += wxS(" breakline=\"true\"");
@@ -163,10 +163,6 @@ bool SqrtCell::BreakUp() {
   m_innerCell->last()->SetNextToDraw(m_close);
   m_close->SetNextToDraw(m_nextToDraw);
   m_nextToDraw = m_open;
-
-  ResetCellListSizes();
-  m_height = 0;
-  m_center = 0;
   return true;
 }
 
