@@ -32,17 +32,17 @@
 */
 
 /*! This class represents a square root
-  
+
   In the case that this cell is broken into two lines in the order of
-  m_nextToDraw this cell is represented by the following individual 
+  m_nextToDraw this cell is represented by the following individual
   cells:
-  
+
   - The SqrtCell itself
   - The opening "sqrt("
   - The contents
   - The closing ")".
-   
-  If it isn't broken into multiple cells m_nextToDraw points to the 
+
+  If it isn't broken into multiple cells m_nextToDraw points to the
   cell that follows this Cell.
 */
 class SqrtCell final : public Cell
@@ -53,9 +53,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 3; }
+  size_t GetInnerCellCount() const override { return 3; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_open)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_open)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
 
@@ -91,7 +91,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_SqrtCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
