@@ -34,9 +34,9 @@ public:
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
   const CellTypeInfo &GetInfo() override;
 
-  int GetInnerCellCount() const override { return 2; }
+  size_t GetInnerCellCount() const override { return 2; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_baseCell)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_baseCell)[index].get(); }
 
   void Recalculate(AFontSize fontsize) override;
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
@@ -50,7 +50,7 @@ public:
 
   void SetAltCopyText(const wxString &text) override { m_altCopyText = text; }
   const wxString &GetAltCopyText() const override { return m_altCopyText; }
-  
+
 private:
   //! Text that should end up on the clipboard if this cell is copied as text.
   wxString m_altCopyText;
@@ -64,7 +64,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_SubCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
