@@ -35,9 +35,9 @@ public:
   const CellTypeInfo &GetInfo() override;
   std::unique_ptr<Cell> Copy(GroupCell *group) const override;
 
-  int GetInnerCellCount() const override { return 5; }
+  size_t GetInnerCellCount() const override { return 5; }
   // cppcheck-suppress objectIndex
-  Cell *GetInnerCell(int index) const override { return (&m_baseCell)[index].get(); }
+  Cell *GetInnerCell(size_t index) const override { return (&m_baseCell)[index].get(); }
 
   void SetIndex(std::unique_ptr<Cell> &&index);
   void SetExponent(std::unique_ptr<Cell> &&expt);
@@ -45,7 +45,7 @@ public:
   void SetPreSup(std::unique_ptr<Cell> &&index);
   void SetPostSub(std::unique_ptr<Cell> &&index);
   void SetPostSup(std::unique_ptr<Cell> &&index);
-  
+
   void Recalculate(AFontSize fontsize) override;
 
   void Draw(wxPoint point, wxDC *dc, wxDC *antialiassingDC) override;
@@ -58,7 +58,7 @@ public:
   wxString ToXML() const override;
 
   wxString GetDiffPart() const override;
-  
+
   void SetAltCopyText(const wxString &text) override { m_altCopyText = text; }
   const wxString &GetAltCopyText() const override { return m_altCopyText; }
 
@@ -82,7 +82,7 @@ private:
 
 //** Bitfield objects (0 bytes)
 //**
-  static void InitBitFields()
+  static void InitBitFields_SubSubCell()
     { // Keep the initialization order below same as the order
       // of bit fields in this class!
     }
