@@ -36,7 +36,7 @@ static wxString cellContents(wxS("?"));
 
 VisiblyInvalidCell::VisiblyInvalidCell(GroupCell *group, Configuration *config)
   : TextCell(group, config, cellContents, TS_ERROR) {
-  InitBitFields();
+  InitBitFields_VisiblyInvalidCell();
   // We cannot do this at the startup of the program as we first need to wait
   // for the language selection to take place.
   // NOTE: static variables are initialized exactly 0 or 1 times, so the below
@@ -47,14 +47,14 @@ VisiblyInvalidCell::VisiblyInvalidCell(GroupCell *group, Configuration *config)
 VisiblyInvalidCell::VisiblyInvalidCell(GroupCell *group, Configuration *config,
                                        wxString &&toolTip)
   : TextCell(group, config, cellContents, TS_ERROR) {
-  InitBitFields();
+  InitBitFields_VisiblyInvalidCell();
   SetToolTip(std::move(toolTip));
 }
 
 VisiblyInvalidCell::VisiblyInvalidCell(GroupCell *group, Configuration *config,
                                        const wxString *toolTip)
   : TextCell(group, config, cellContents, TS_ERROR) {
-  InitBitFields();
+  InitBitFields_VisiblyInvalidCell();
   SetToolTip(toolTip);
 }
 
