@@ -26,6 +26,7 @@
 */
 
 #include "main.h"
+#include "Maxima.h"
 #include "Dirstructure.h"
 #include "StackToStdErr.h"
 #include "wxMathml.h"
@@ -50,7 +51,7 @@
 #include <windows.h>
 #endif
 
-#include "ConfigDialogue.h"
+#include "dialogs/ConfigDialogue.h"
 #include "Version.h"
 #include "examples/CASvsProgrammingLanguage.h"
 #include "examples/diffEquations.h"
@@ -102,17 +103,15 @@ wxCmdLineParser cmdLineParser;
 static const wxCmdLineEntryDesc cmdLineDesc[] = {
   {wxCMD_LINE_SWITCH, "v", "version", "Output the version info.",
    wxCMD_LINE_VAL_NONE, 0},
-  /* Usually wxCMD_LINE_OPTION_HELP is used with the following option, but
-   * that displays a message using its own window and we want the message on
-   * the command line.  If a user enters a command line option, he expects
-   * probably an answer just on the command line... */
   {wxCMD_LINE_SWITCH, "h", "help", "Show this help message.",
-   wxCMD_LINE_VAL_NONE, 0},
+   wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP},
   {wxCMD_LINE_OPTION, "o", "open", "Open a file.", wxCMD_LINE_VAL_STRING, 0},
   {wxCMD_LINE_SWITCH, "e", "eval", "Evaluate the file after opening it.",
    wxCMD_LINE_VAL_NONE, 0},
   {wxCMD_LINE_SWITCH, "", "single_process",
-   "Open all files from within the same process.", wxCMD_LINE_VAL_NONE, 0},
+   "Open all worksheets from within the same process.", wxCMD_LINE_VAL_NONE, 0},
+  {wxCMD_LINE_SWITCH, "", "single_thread",
+   "Run all background tasks from within the main thread.", wxCMD_LINE_VAL_NONE, 0},
   {wxCMD_LINE_SWITCH, "b", "batch",
    "Run the file and exit afterwards. Halts on questions and stops on "
    "errors.",
@@ -179,6 +178,10 @@ int WINAPI WinMain(_In_ HINSTANCE hI, _In_opt_ HINSTANCE hPrevI, _In_ LPSTR lpCm
 
 bool MyApp::OnInit() {
   wxLogStderr noErrorDialogs;
+  // Needed for making wxSocket work for multiple threads. We currently don't
+  // use this feature. But it doesn't harm to be prepared
+  wxSocketBase::Initialize();
+
   m_translations = std::unique_ptr<wxTranslations>(new wxTranslations());
   wxTranslations::Set(m_translations.get());
   // connect to wxMaxima. We therefore delay all output to the log until there
@@ -301,15 +304,11 @@ bool MyApp::OnInit() {
   if (cmdLineParser.Found(wxS("single_process")))
     m_allWindowsInOneProcess = true;
 
-  if (cmdLineParser.Found(wxS("h"))) {
-    std::cout << "A feature-rich graphical user interface for the computer "
-      "algebra system Maxima\n";
-    std::cout << cmdLineParser.GetUsageString();
-    exit(0);
-  }
+  if (cmdLineParser.Found(wxS("single_thread")))
+    Configuration::UseThreads(false);
 
   if (cmdLineError != 0)
-    exit(-1);
+    exit(1);
 
   wxString ini, file;
   // Attention: The config file is changed by
@@ -331,7 +330,7 @@ bool MyApp::OnInit() {
     Configuration::SetDebugmode();
 
   if (cmdLineParser.Found(wxS("pipe")))
-    wxMaxima::PipeToStdout();
+    Maxima::SetPipeToStdErr(true);
 
   if (cmdLineParser.Found(wxS("exit-on-error")))
     wxMaxima::ExitOnError();
@@ -408,12 +407,11 @@ bool MyApp::OnInit() {
 #endif
 
   if (cmdLineParser.Found(wxS("v"))) {
-    std::cout << "wxMaxima ";
-    std::cout << GITVERSION;
-#if defined(WXMAXIMA_GIT_VERSION)
-    std::cout << " (Git version: " << WXMAXIMA_GIT_VERSION << ")";
+#if defined(WXMAXIMA_GIT_SHORT_HASH)
+    wxMessageOutput::Get()->Printf("wxMaxima %s (Git version: %s)\n", GITVERSION, WXMAXIMA_GIT_SHORT_HASH);
+#else
+    wxMessageOutput::Get()->Printf("wxMaxima %s\n", GITVERSION);
 #endif
-    std::cout << "\n";
     exit(0);
   }
 
@@ -457,7 +455,7 @@ bool MyApp::OnInit() {
   return true;
 }
 
-int MyApp::OnExit() { return 0; }
+int MyApp::OnExit() { return wxMaxima::GetExitCode(); }
 
 int MyApp::OnRun() {
   wxLogStderr noErrorDialogs;
@@ -468,12 +466,19 @@ int MyApp::OnRun() {
 void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
                       bool exitAfterEval, unsigned char *wxmData,
                       std::size_t wxmLen) {
-  int numberOfWindows = wxMaximaFrame::m_topLevelWindows.size();
 
   wxString title = _("wxMaxima");
   if (file.Length() > 0)
     title = file;
 
+  int numberOfWindows = 1; // TODO: Count
+
+  wxWindowList::compatibility_iterator node = wxTopLevelWindows.GetFirst();
+  while (node) {
+    numberOfWindows++;
+    node = node->GetNext();
+  }
+
   if (numberOfWindows > 1)
     title = wxString::Format(_("wxMaxima %d"), numberOfWindows);
 
@@ -495,10 +500,9 @@ void MyApp::NewWindow(const wxString &file, bool evalOnStartup,
     }
     initialContents += _(block);
   }
-  wxMaxima *frame = new wxMaxima(NULL, -1, title, file, initialContents);
+  wxMaxima *frame = new wxMaxima(NULL, wxID_ANY, title, file, initialContents);
 
   frame->EvalOnStartup(evalOnStartup);
-  wxMaximaFrame::m_topLevelWindows.push_back(frame);
   frame->ExitAfterEval(exitAfterEval);
   frame->Show(true);
   frame->ShowTip(false);
@@ -587,7 +591,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
         args.push_back("--logtostderr");
       if (Configuration::GetDebugmode())
         args.push_back("--debug");
-      if (wxMaxima::GetPipeToStdout())
+      if (Maxima::GetPipeToStdErr())
         args.push_back("--pipe");
       if (wxMaxima::GetExitOnError())
         args.push_back("--exit-on-error");
@@ -608,7 +612,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
       // Additionally wxExecute expects these C strings in a C array.
       // Let's generate an unique pointer to that one so C++ automatically destroys it
       // once it is no more needed.
-      std::unique_ptr<char *> args_array(new char*[args.size() + 2]);
+      std::unique_ptr<char*[]> args_array(new char*[args.size() + 2]);
       wxCharBuffer executableName(wxStandardPaths::Get().GetExecutablePath().mb_str());
       args_array.get()[0] = executableName.data();;
       args_array.get()[args.size() + 1] = NULL;
@@ -625,7 +629,7 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
   }
   else if(ev.GetId() == wxID_PREFERENCES) {
     Configuration config;
-    ConfigDialogue *configW = new ConfigDialogue(NULL, &config);
+    ConfigDialogue *configW = new ConfigDialogue(NULL);
     configW->Centre(wxBOTH);
     if (configW->ShowModal() == wxID_OK)
       configW->WriteSettings();
@@ -633,20 +637,9 @@ void MyApp::OnFileMenu(wxCommandEvent &ev) {
     configW->Destroy();
     wxConfig::Get()->Flush();
   }
-  else if(ev.GetId() ==  wxID_EXIT) {
-    for (wxMaximaFrame *win : wxMaximaFrame::m_topLevelWindows) {
-      wxASSERT(win);
-      wxCloseEvent *event = new wxCloseEvent(wxEVT_CLOSE_WINDOW);
-      event->SetCanVeto(true);
-      event->SetLoggingOff(false);
-      if(win)
-        win->GetEventHandler()->QueueEvent(event);
-    }
-    if (wxMaximaFrame::m_topLevelWindows.empty())
-      wxExit();
-  }
 }
 
+
 void MyApp::MacNewFile() {
   wxWindow *frame = GetTopWindow();
   if (frame == NULL)
