@@ -41,14 +41,14 @@ class wxImagePanel : public wxPanel
   wxImage m_image;
   wxBitmap m_resized;
   int m_w, m_h;
- 
+
 public:
-  wxImagePanel(wxWindow* parent, unsigned char *data, size_t len);
-  void Load(unsigned char *data, size_t len);
- 
+  wxImagePanel(wxWindow* parent, unsigned char *data, std::size_t len);
+  void Load(unsigned char *data, std::size_t len);
+
   void paintEvent(wxPaintEvent & evt);
   void paintNow();
-  void OnSize(wxSizeEvent& event); 
+  void OnSize(wxSizeEvent& event);
 };
 
 #endif // IMAGEPANEL_H
