@@ -2166,24 +2166,17 @@ Submit bug reports by following the 'New issue' link on that page."))
 
 ;; A function that determines all symbols for autocompletion
 (defun wxPrint_autocompletesymbols ()
-  (finish-output)
   (format t "<wxxml-symbols>")
-  ;; Function names and rules
-  (format t "~{~a~^$~}"
-	  (append (mapcar #'$print_function (cdr ($append (eval '$functions) (eval '$macros))))
-		  (mapcar #'print_value (cdr ($append (eval '$values) (eval '$rules))))))
-  ;; Idea from Robert Dodier:
-  ;; Variables defined with mdef don't appear in $values nor do they in $myoptions
-  ;; but they appear in *variable-initial-values*
-  (maphash (lambda (key val)
-	     (declare (ignore val))
-	     (if (eq (char (format nil "~a" key) 0) #\$ )
-		 (format t "~a" (print_value key))))
-	   *variable-initial-values*)
-
-  ;;    (mapcar (lambda(key) (if (eq (char (format nil "~a" key) 0) #\$ ) (symbol-to-xml (make-symbol key)))) (wx-list-all-maxima-vars))
-
-  ;; ezunits publishes all known units in a function.
+  (do-symbols
+      (s (find-package 'maxima))
+    (let ((str (format nil "~a" s)))
+      (if (< 1 (length str))
+          (if (string= (subseq str 0 1) "$")
+              (format t "<value>~a</value>"
+                      (wxxml-fix-string (format nil "~a"
+                                                (stripdollar (maybe-invert-string-case str))))
+                      )))))
+  ;;ezunits publishes all known units in a function.
   (if (boundp '$known_units)
       (no-warning
        (format t "~{~a~^$~}"
@@ -2210,14 +2203,14 @@ Submit bug reports by following the 'New issue' link on that page."))
   (if (eq $display2d nil)
       (format t "false")
       (format t "true"))
-  (format t "</value></variable>~%"))
+  (format t "</value></variable>"))
 
 (defun wx-query-variable (var)
-  (format t "<variables>~%<variable>~%<name>~a</name>" (wxxml-fix-string (maybe-invert-string-case var)))
+  (format t "<variables><variable><name>~a</name>" (wxxml-fix-string (maybe-invert-string-case var)))
   (ignore-errors
     (let (($display2d nil))
       (mtell "<value>~M</value>" (wxxml-fix-string ($sconcat (meval (intern var)))))))
-  (format t "</variable>~%</variables>~%"))
+  (format t "</variable></variables>~%"))
 
 (defun wx-print-variables ()
   (finish-output)
@@ -2242,15 +2235,7 @@ Submit bug reports by following the 'New issue' link on that page."))
   (format t "</variables>~%")
   (finish-output)
   )
-
-					;tttt
-					;  (defun wx-list-all-maxima-vars () (let ((lst ())) (do-symbols (s (find-package 'maxima)) (push s lst)) lst))
-					; 	       (if (eq (char (format nil "~a" key) 0) #\$ )
-
-					;  (let ((lst ())) (do-symbols (s (find-package 'maxima)) (push s lst)) lst)
-					; 	       (if (eq (char (format nil "~a" key) 0) #\$ )
-
-					;    (mapcar (lambda(key) (if (eq (char (format nil "~a" key) 0) #\$ ) (symbol-to-xml (make-symbol key)))) (wx-list-all-maxima-vars))
+					;
 
 
 ;; WxMaxima reads these variables and sets several checkboxes in the Menu according to these
@@ -2380,8 +2365,6 @@ Submit bug reports by following the 'New issue' link on that page."))
 
 (putprop '$table_form t 'evfun)
 
-(wxPrint_autocompletesymbols)
-
 (no-warning
  (defun mredef-check (fnname)
    (declare (ignore fnname))
@@ -2480,10 +2463,8 @@ Submit bug reports by following the 'New issue' link on that page."))
 (format t "</suppressOutput>~%")
 ;; Publish all new global variables maxima might contain to wxMaxima's
 ;; autocompletion feature.
-(wxPrint_autocompletesymbols)
 (wx-print-variables)
 (wx-print-gui-variables)
-(format t "~%")
 ;; Declare that we want all builtins with underscore not to be printed with subscript
 (maphash (lambda (key val)
 	   (declare (ignore val))
