@@ -75,7 +75,6 @@
 #define MAXIMAPOLLMSECS 2000
 
 class Maxima; // The Maxima process interface
-class MaximaEvent;
 
 /* The top-level window and the main application logic
 
@@ -91,10 +90,6 @@ public:
   virtual ~wxMaxima();
 
   wxString EscapeFilenameForShell(wxString name);
-  //! Pipe maxima's output to stdout
-  static void PipeToStdout(){m_pipeToStderr = true;}
-  //! Pipe maxima's output to stdout?
-  static bool GetPipeToStdout(){return m_pipeToStderr;}
   //! Exit if we encounter an error
   static void ExitOnError(){m_exitOnError = true;}
   //! Do we exit if we encounter an error?
@@ -191,21 +186,26 @@ public:
   //! The maxima command, if we use the --maxima=<str> command. If empty we use the configured path, not a command line option --maxima=<str>.
   static const wxString Get_Maxima_Commandline_Filename() {return maxima_command_line_filename;}
 
+  static int GetExitCode(){return m_exitCode;}
 
 private:
   //! If we use the command line option --maxima=<str>, this variable is not-empty and contains its name
   static wxString maxima_command_line_filename;
+  //! True if maxima has sent us the correct Auth string
   bool m_maximaAuthenticated = false;
+  //! True if maxima has failed to authenticate and we therefore distrust its data.
   bool m_discardAllData = false;
+  //! The string Maxima needs to know in order to prove to be the correct process
   wxString m_maximaAuthString;
+  //! The object that allows maxima to send us GUI events for testing purposes
   MaximaIPC m_ipc{this};
-  static bool m_pipeToStderr;
+  //! True if we want to exit if we encounter an error
   static bool m_exitOnError;
+  //! Extra arguments wxMaxima's command line told us to pass to maxima
   static wxString m_extraMaximaArgs;
   //! The variable names to query for the variables pane and for internal reasons
   std::vector<wxString> m_varNamesToQuery;
 
-  bool m_isLogTarget;
   //! Is true if opening the file from the command line failed before updating the statusbar.
   bool m_openInitialFileError;
   //! Escape strings into a format lisp accepts
@@ -227,8 +227,6 @@ private:
   int m_oldFindFlags;
   //! On opening a new file we only need a new maxima process if the old one ever evaluated cells.
   bool m_hasEvaluatedCells;
-  //! Searches for maxima's output prompts
-//  static wxRegEx m_outputPromptRegEx;
   //! The number of output cells the current command has produced so far.
   long m_outputCellsFromCurrentCommand;
   //! The maximum number of lines per command we will display
@@ -257,7 +255,6 @@ private:
   //! The buffer all text from maxima is stored in before converting it to a wxString.
   wxMemoryBuffer m_uncompletedChars;
 
-
 protected:
   //! Invoke our standard wizard that generates maxima commands
   void CommandWiz(const wxString &title,
@@ -346,16 +343,6 @@ protected:
     is too busy to execute the idle task at all.
   */
   void OnIdle(wxIdleEvent &event);
-  /*! Read and interpret the new data from maxima
-
-    We don't interpret this data directly in the idle event since if we
-    block somewhere in the idle event we block gnome.
-    \return
-    - true, if there was new data
-    - false, if there wasn't any new data.
-  */
-  bool InterpretDataFromMaxima(const wxString &newData);
-  bool InterpretDataFromMaxima();
   bool m_dataFromMaximaIs;
 
   void MenuCommand(const wxString &cmd);           //!< Inserts command cmd into the worksheet
@@ -382,7 +369,8 @@ protected:
     \param event The event that triggered calling this function.
   */
   void ShowPane(wxCommandEvent &event);            //<! Makes a sidebar visible
-  void OnProcessEvent(wxProcessEvent &event);      //
+  void OnMaximaClose(wxProcessEvent &event);      //
+  void OnMaximaClose();      //
   void OnGnuplotClose(wxProcessEvent &event);      //
   void OnGnuplotQueryTerminals(wxProcessEvent &event);      //
   void PopupMenu(wxCommandEvent &event);           //
@@ -404,7 +392,7 @@ protected:
   void OnMaximaConnect();
 
   //! Maxima sends or receives data, or disconnects
-  void MaximaEvent(::MaximaEvent &event);
+  void MaximaEvent(wxThreadEvent &event);
 
   //! Server event: Maxima connects
   void ServerEvent(wxSocketEvent &event);
@@ -424,6 +412,7 @@ protected:
      maths instead).
   */
   TextCell *ConsoleAppend(wxString s, CellType type, const wxString &userLabel = {});        //!< append maxima output to console
+  void ConsoleAppend(wxXmlDocument xml, CellType type, const wxString &userLabel = {});        //!< append maxima output to console
 
   enum AppendOpt { NewLine = 1, BigSkip = 2, PromptToolTip = 4, DefaultOpt = NewLine|BigSkip };
   void DoConsoleAppend(wxString s, CellType type, AppendOpt opts = AppendOpt::DefaultOpt,
@@ -507,18 +496,7 @@ protected:
     \param data The string ReadFirstPrompt() does read its data from.
     After leaving this function data is empty again.
   */
-  void ReadFirstPrompt(wxString &data);
-
-  /*! Reads an XML tag or a piece of status text from maxima's output
-
-    \todo Is there any way to handle the (perhaps, thanks to the flush commands in maxima)
-    theoretical case that maxima might stop sending data in the middle of an XML tag
-    and then resume sending data with the next XML packet?
-  */
-  bool ParseNextChunkFromMaxima(wxString &data);
-
-  //! Find the end of a tag in wxMaxima's output.
-  long FindTagEnd(const wxString &data, const wxString &tag);
+  void ReadFirstPrompt(const wxString &data);
 
   /*! Reads text that isn't enclosed between xml tags.
 
@@ -533,16 +511,16 @@ protected:
 
     After processing the input prompt it is removed from data.
   */
-  void ReadPrompt(wxString &data);
+  void ReadPrompt(const wxString &data);
 
   /*! Reads the output of wxstatusbar() commands
 
     wxstatusbar allows the user to give and update visual feedback from long-running
     commands and makes sure this feedback is deleted once the command is finished.
   */
-  void ReadStatusBar(wxString &data);
+  void ReadStatusBar(const wxXmlDocument &xmldoc);
   //! Read a manual topic name so we can jump to the right documentation page
-  void ReadManualTopicNames(wxString &data);
+  void ReadManualTopicNames(const wxXmlDocument &xmldoc);
 
   /*! Reads the math cell's contents from Maxima.
 
@@ -552,26 +530,26 @@ protected:
 
     After processing the status bar marker is removed from data.
   */
-  void ReadMath(wxString &data);
+  void ReadMath(const wxXmlDocument &xml);
 
   /*! Reads autocompletion templates we get on definition of a function or variable
 
     After processing the templates they are removed from data.
   */
 
-  void ReadMaximaIPC(wxString &data){m_ipc.ReadInputData(data);}
-  void ReadLoadSymbols(wxString &data);
+  void ReadMaximaIPC(const wxString &data){m_ipc.ReadInputData(data);}
+  void ReadLoadSymbols(const wxXmlDocument &data);
 
   //! Read (and discard) suppressed output
-  void ReadSuppressedOutput(wxString &data);
+  void ReadSuppressedOutput(const wxString &data);
 
   /*! Reads the variable values maxima advertises to us
    */
-  void ReadVariables(wxString &data);
+  void ReadVariables(const wxXmlDocument &xmldoc);
 
   /*! Reads the "add variable to watch list" tag maxima can send us
    */
-  void ReadAddVariables(wxString &data);
+  void ReadAddVariables(const wxXmlDocument &xmldoc);
   //! Called if maxima tells us the value of the maxima variable gentranlang.
   void VariableActionGentranlang(const wxString &value);
   //! Called if maxima tells us the value of the maxima variable numer.
@@ -640,6 +618,7 @@ protected:
   wxString m_maximaVariable_altdisplay2d;
   wxString m_maximaVariable_engineeringFormat;
   bool m_readMaximaVariables = false;
+  bool m_updateAutocompletion = true;
   /*! How much CPU time has been used by the system until now? Used by GetMaximaCPUPercentage.
 
     \return The CPU time elapsed in the same unit as GetMaximaCpuTime(); -1 means: Unable to determine this value.
@@ -755,38 +734,22 @@ protected:
   */
   std::unique_ptr<wxSocketServer,  ServerDeleter> m_server;
 
-  wxProcess *m_process;
+  wxProcess *m_maximaProcess;
   //! The stdout of the maxima process
   wxInputStream *m_maximaStdout;
   //! The stderr of the maxima process
   wxInputStream *m_maximaStderr;
+  //! The port the actual maxima process (not its wrapper script) runs at
   int m_port;
-  /*! The end of Maxima's current uninterpreted output, see m_currentOutput.
-
-    If we just want to look if Maxima's current output contains an ending tag
-    this is the place we can search in fast.
-
-    wxEmptyString means that the current output isn't long enough to make
-    creating this string worthwhile.
-  */
-  wxString m_currentOutputEnd;
-  //! All from maxima's current output we still haven't interpreted
-  wxString m_currentOutput;
   //! A marker for the start of maths
   static wxString m_mathPrefix1;
   //! A marker for the start of maths
   static wxString m_mathPrefix2;
-  //! A marker for the end of maths
-  static wxString m_mathSuffix1;
-  //! A marker for the end of maths
-  static wxString m_mathSuffix2;
   //! The marker for the start of a input prompt
   static wxString m_promptPrefix;
 public:
   //! The marker for the end of a input prompt
   const static wxString m_promptSuffix;
-  //! Remove the said window from the list of toplevel windows
-  static void DelistTopLevelWindow(wxMaxima *);
 protected:
     //! Is called when we get a new list of demo files
   //! Is called when we get a new list of demo files
@@ -800,38 +763,8 @@ protected:
 
   //! Sets gnuplot's command name and tries to determine gnuplot's path
   void GnuplotCommandName(wxString gnuplot);
-  //! The marker for the start of a variables section
-  static wxString m_variablesPrefix;
-  //! The marker for the end of a variables section
-  static wxString m_variablesSuffix;
-  //! The marker for the start of a prompt
-//  static wxString m_outputPromptPrefix;
-  //! The marker for the end of a prompt
-//  static wxString m_outputPromptSuffix;
-  //! The marker for the start of a variables section
-  static wxString m_statusbarPrefix;
-  //! The marker for the end of a variables section
-  static wxString m_statusbarSuffix;
-  //! The marker for the start of a "add variables" section
-  static wxString m_jumpManualPrefix;
-  //! The marker for the end of a variables section
-  static wxString m_jumpManualSuffix;
-  //! The marker for the start of a "add variables" section
-  static wxString m_addVariablesPrefix;
-  //! The marker for the end of a "add variables" section
-  static wxString m_addVariablesSuffix;
-  //! The marker for the start of a list of autocompletion templates
-  static wxString m_symbolsPrefix;
-  //! The marker for the end of a list of autocompletion templates
-  static wxString m_symbolsSuffix;
-  //! The marker that tells to start suppressing any output from maxima
-  static wxString m_suppressOutputPrefix;
-  //! The marker that tells to stop to suppress any output from maxima
-  static wxString m_suppressOutputSuffix;
   //! The first prompt maxima will output
   static wxString m_firstPrompt;
-  //! An empty wxxml symbols section
-  static wxString m_emptywxxmlSymbols;
   bool m_dispReadOut;               //!< what is displayed in statusbar
   int m_gnuplot_process_id;
   int m_maxima_process_id;
@@ -867,20 +800,11 @@ private:
   //! The value of maxima's logexpand variable
   wxString m_logexpand;
   //! A pointer to a method that handles a text chunk
-  typedef void (wxMaxima::*ParseFunction)(wxString &s);
   typedef void (wxMaxima::*VarReadFunction)(const wxString &value);
   typedef void (wxMaxima::*VarUndefinedFunction)();
-#if wxCHECK_VERSION(3, 3, 0) || wxUSE_STL
-  typedef std::unordered_map <wxString, ParseFunction> ParseFunctionHash;
-  typedef std::unordered_map <wxString, VarReadFunction> VarReadFunctionHash;
-  typedef std::unordered_map <wxString, VarUndefinedFunction> VarUndefinedFunctionHash;
-#else
-  WX_DECLARE_STRING_HASH_MAP(ParseFunction, ParseFunctionHash);
-  WX_DECLARE_STRING_HASH_MAP(VarReadFunction, VarReadFunctionHash);
-  WX_DECLARE_STRING_HASH_MAP(VarUndefinedFunction, VarUndefinedFunctionHash);
-#endif
-  //! A list of XML tags we know and what we want to do if we encounter them
-  static ParseFunctionHash m_knownXMLTags;
+  typedef std::unordered_map <wxString, VarReadFunction, wxStringHash> VarReadFunctionHash;
+  typedef std::unordered_map <wxString, VarUndefinedFunction,
+                              wxStringHash> VarUndefinedFunctionHash;
   //! A list of actions we want to execute if we are sent the contents of specific variables
   static VarReadFunctionHash m_variableReadActions;
   //! A list of actions we want to execute if certain variables are undefined;
