@@ -47,7 +47,7 @@
 #include "wizards/ScrollingGenWizPanel.h"
 #include "Worksheet.h"
 #include "sidebars/SymbolsSidebar.h"
-#include "HelpBrowser.h"
+#include "sidebars/HelpBrowser.h"
 #include "RecentDocuments.h"
 #include "Version.h"
 #include "MainMenuBar.h"
@@ -230,8 +230,6 @@ protected:
 
   wxString wxMaximaManualLocation();
 public:
-  //! The list of toplevel windows we currently maintain
-  static std::vector<wxMaximaFrame *> m_topLevelWindows;
 
   /*! Makes this window the debug log target of all windows from this maxima process
 
@@ -260,6 +258,19 @@ private:
   Create the menus.
 */
   void SetupMenu();
+  void SetupFileMenu();
+  void SetupEditMenu();
+  void SetupViewMenu();
+  void SetupCellMenu();
+  void SetupMaximaMenu();
+  void SetupEquationsMenu();
+  void SetupMatrixMenu();
+  void SetupCalculusMenu();
+  void SetupSimplifyMenu();
+  void SetupListMenu();
+  void SetupPlotMenu();
+  void SetupNumericMenu();
+  void SetupHelpMenu();
 
 public:
   void StatusText(const wxString &text, bool saveInLog = true);
@@ -288,7 +299,7 @@ protected:
   void OnMenuStatusText(wxMenuEvent &event);
   std::unordered_map<wxWindowID, wxString> m_demoFilesIDs;
 
-  SymbolsSidebar *m_symbolsSidebar;
+  SymbolsSidebar *m_symbolsSidebar = NULL;
   //! The current length of the evaluation queue of commands we still need to send to maxima
   int m_EvaluationQueueLength;
   //! Do we need to update the display showing the evaluation queue length?
